@@ -13,22 +13,22 @@ print(Demos_Zend_Service_LiveDocx_Helper::wrapLine(
     PHP_EOL)
 );
 
-$phpLiveDocx = new Zend_Service_LiveDocx_MailMerge();
+$mailMerge = new Zend_Service_LiveDocx_MailMerge();
 
-$phpLiveDocx->setWsdl('https://api.example.com/1.2/mailmerge.asmx?WSDL')
-            ->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
-            ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
+$mailMerge->setWsdl('https://api.example.com/1.2/mailmerge.asmx?WSDL')
+          ->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
+          ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
 
-$phpLiveDocx->getTemplateFormats(); // then call methods as usual
+$mailMerge->getTemplateFormats(); // then call methods as usual
 
 printf('Username : %s%sPassword : %s%s    WSDL : %s%s%s',
-    $phpLiveDocx->getUsername(),
+    $mailMerge->getUsername(),
     PHP_EOL,
-    $phpLiveDocx->getPassword(),
+    $mailMerge->getPassword(),
     PHP_EOL,
-    $phpLiveDocx->getWsdl(),
+    $mailMerge->getWsdl(),
     PHP_EOL,
     PHP_EOL
 );
 
-unset($phpLiveDocx, $mySoapClient);
\ No newline at end of file
+unset($mailMerge, $mySoapClient);
\ No newline at end of file
