@@ -3,10 +3,10 @@
 require_once dirname(__FILE__) . '/../../common.php';
 
 
-$phpLiveDocx = new Zend_Service_LiveDocx_MailMerge();
+$mailMerge = new Zend_Service_LiveDocx_MailMerge();
 
-$phpLiveDocx->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
-            ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
+$mailMerge->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
+          ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
 
 system('clear');
 
@@ -15,9 +15,9 @@ print(Demos_Zend_Service_LiveDocx_Helper::wrapLine(
     PHP_EOL . 
     PHP_EOL . 'The following fonts are installed on the backend server and may be used in templates. Fonts used in templates, which are NOT listed below, will be substituted. If you would like to use a font, which is not installed on the backend server, please contact your LiveDocx provider.' .
     PHP_EOL . 
-    PHP_EOL . Demos_Zend_Service_LiveDocx_Helper::arrayDecorator($phpLiveDocx->getFontNames()) . 
+    PHP_EOL . Demos_Zend_Service_LiveDocx_Helper::arrayDecorator($mailMerge->getFontNames()) . 
     PHP_EOL . 
     PHP_EOL)
 );
 
-unset($phpLiveDocx);
\ No newline at end of file
+unset($mailMerge);
\ No newline at end of file
