@@ -11,15 +11,15 @@ print(Demos_Zend_Service_LiveDocx_Helper::wrapLine(
     PHP_EOL)
 );
 
-$phpLiveDocx = new Zend_Service_LiveDocx_MailMerge();
+$mailMerge = new Zend_Service_LiveDocx_MailMerge();
 
-$phpLiveDocx->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
-            ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
+$mailMerge->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
+          ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
 
 $counter = 1;
-foreach ($phpLiveDocx->listTemplates() as $result) {
+foreach ($mailMerge->listTemplates() as $result) {
     printf('%d) %s', $counter, $result['filename']);
-    $template = $phpLiveDocx->downloadTemplate($result['filename']);
+    $template = $mailMerge->downloadTemplate($result['filename']);
     file_put_contents('downloaded-' . $result['filename'], $template);
     print(" - DOWNLOADED.\n");
     $counter++;
@@ -27,4 +27,4 @@ foreach ($phpLiveDocx->listTemplates() as $result) {
 
 print(PHP_EOL);
 
-unset($phpLiveDocx);
\ No newline at end of file
+unset($mailMerge);
\ No newline at end of file
