@@ -11,13 +11,13 @@ print(Demos_Zend_Service_LiveDocx_Helper::wrapLine(
     PHP_EOL)
 );
 
-$phpLiveDocx = new Zend_Service_LiveDocx_MailMerge();
+$mailMerge = new Zend_Service_LiveDocx_MailMerge();
 
-$phpLiveDocx->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
-            ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
+$mailMerge->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
+          ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
 
 print('Checking whether a template is available... ');
-if (true === $phpLiveDocx->templateExists('template-1.docx')) {
+if (true === $mailMerge->templateExists('template-1.docx')) {
     print('EXISTS. ');
 } else {
     print('DOES NOT EXIST. ');
@@ -26,4 +26,4 @@ print('DONE' . PHP_EOL);
 
 print(PHP_EOL);
 
-unset($phpLiveDocx);
\ No newline at end of file
+unset($mailMerge);
\ No newline at end of file
