@@ -11,19 +11,19 @@ print(Demos_Zend_Service_LiveDocx_Helper::wrapLine(
     PHP_EOL)
 );
 
-$phpLiveDocx = new Zend_Service_LiveDocx_MailMerge();
+$mailMerge = new Zend_Service_LiveDocx_MailMerge();
 
-$phpLiveDocx->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
-            ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
+$mailMerge->setUsername(DEMOS_ZEND_SERVICE_LIVEDOCX_USERNAME)
+          ->setPassword(DEMOS_ZEND_SERVICE_LIVEDOCX_PASSWORD);
 
 print('Uploading template... ');
-$phpLiveDocx->uploadTemplate('template-1.docx');
+$mailMerge->uploadTemplate('template-1.docx');
 print('DONE.' . PHP_EOL);
 
 print('Uploading template... ');
-$phpLiveDocx->uploadTemplate('template-2.docx');
+$mailMerge->uploadTemplate('template-2.docx');
 print('DONE.' . PHP_EOL);
 
 print(PHP_EOL);
 
-unset($phpLiveDocx);
\ No newline at end of file
+unset($mailMerge);
\ No newline at end of file
