@@ -17,7 +17,7 @@
  * @subpackage  View
  * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license     http://framework.zend.com/license/new-bsd     New BSD License
- * @version     $Id: Container.php 20751 2010-01-29 11:14:09Z beberlei $
+ * @version     $Id: Container.php 24189 2011-07-05 15:08:03Z matthew $
  */
 
 /**
@@ -239,10 +239,20 @@ class ZendX_JQuery_View_Helper_JQuery_Container
      */
     public function setCdnSsl($flag)
     {
-        $this->_loadSslCdnPath = $flag;
+        $this->_loadSslCdnPath = (boolean) $flag;
         return $this;
     }
 
+    /**
+     * Get Flag of SSL on CDN
+     *
+     * @return boolean True if SSL is used on CDN
+     */
+    public function getCdnSsl()
+    {
+        return $this->_loadSslCdnPath;
+    }
+
     /**
      * Are we using the CDN?
      *
@@ -829,4 +839,4 @@ class ZendX_JQuery_View_Helper_JQuery_Container
         }
         return $uiPath;
     }
-}
\ No newline at end of file
+}
