@@ -17,7 +17,7 @@
  * @subpackage Value
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ArrayCollection.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: ArrayCollection.php 24473 2011-09-26 19:33:55Z matthew $
  */
 
 /**
@@ -30,6 +30,6 @@
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
-class Zend_Amf_Value_Messaging_ArrayCollection
+class Zend_Amf_Value_Messaging_ArrayCollection extends ArrayObject
 {
 }
