@@ -14,9 +14,9 @@
  *
  * @category   Zend
  * @package    Zend_Pdf
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Parser.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: Parser.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 /** Internally used classes */
@@ -32,7 +32,7 @@ require_once 'Zend/Pdf/StringParser.php';
  * PDF file parser
  *
  * @package    Zend_Pdf
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Pdf_Parser
@@ -367,14 +367,22 @@ class Zend_Pdf_Parser
                 throw new Zend_Pdf_Exception( "Can not open '$source' file for reading." );
             }
 
+            $data = '';
             $byteCount = filesize($source);
+            while ($byteCount > 0 && !feof($pdfFile)) {
+                $nextBlock = fread($pdfFile, $byteCount);
+                if ($nextBlock === false) {
+                    require_once 'Zend/Pdf/Exception.php';
+                    throw new Zend_Pdf_Exception( "Error occured while '$source' file reading." );
+                }
 
-            $data = fread($pdfFile, $byteCount);
-            $byteCount -= strlen($data);
-            while ( $byteCount > 0 && ($nextBlock = fread($pdfFile, $byteCount)) != false ) {
                 $data .= $nextBlock;
                 $byteCount -= strlen($nextBlock);
             }
+            if ($byteCount != 0) {
+                require_once 'Zend/Pdf/Exception.php';
+                throw new Zend_Pdf_Exception( "Error occured while '$source' file reading." );
+            }
             fclose($pdfFile);
 
             $this->_stringParser = new Zend_Pdf_StringParser($data, $factory);
