@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Service_WindowsAzure
  * @subpackage Storage
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Blob.php 14561 2009-05-07 08:05:12Z unknown $
+ * @version    $Id: Table.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 /**
@@ -90,7 +90,7 @@ require_once 'Zend/Service/WindowsAzure/Exception.php';
  * @category   Zend
  * @package    Zend_Service_WindowsAzure
  * @subpackage Storage
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_Storage_Table
@@ -111,14 +111,14 @@ class Zend_Service_WindowsAzure_Storage_Table
 
 	    // Always use SharedKeyLite authentication
 	    $this->_credentials = new Zend_Service_WindowsAzure_Credentials_SharedKeyLite($accountName, $accountKey, $this->_usePathStyleUri);
-	    
+	
 	    // API version
-		$this->_apiVersion = '2009-04-14';
+		$this->_apiVersion = '2009-09-19';
 	}
 	
 	/**
 	 * Check if a table exists
-	 * 
+	 *
 	 * @param string $tableName Table name
 	 * @return boolean
 	 */
@@ -129,13 +129,13 @@ class Zend_Service_WindowsAzure_Storage_Table
 		}
 			
 		// List tables
-        $tables = $this->listTables($tableName);
+        $tables = $this->listTables(); // 2009-09-19 does not support $this->listTables($tableName); all of a sudden...
         foreach ($tables as $table) {
             if ($table->Name == $tableName) {
                 return true;
             }
         }
-        
+
         return false;
 	}
 	
@@ -149,21 +149,22 @@ class Zend_Service_WindowsAzure_Storage_Table
 	public function listTables($nextTableName = '')
 	{
 	    // Build query string
-	    $queryString = '';
+		$queryString = array();
 	    if ($nextTableName != '') {
-	        $queryString = '?NextTableName=' . $nextTableName;
+	        $queryString[] = 'NextTableName=' . $nextTableName;
 	    }
-	    
+	    $queryString = self::createQueryStringFromArray($queryString);
+	
 		// Perform request
 		$response = $this->_performRequest('Tables', $queryString, Zend_Http_Client::GET, null, true);
-		if ($response->isSuccessful()) {	    
+		if ($response->isSuccessful()) {	
 		    // Parse result
 		    $result = $this->_parseResponse($response);	
-		    
+		
 		    if (!$result || !$result->entry) {
 		        return array();
 		    }
-	        
+	
 		    $entries = null;
 		    if (count($result->entry) > 1) {
 		        $entries = $result->entry;
@@ -172,11 +173,11 @@ class Zend_Service_WindowsAzure_Storage_Table
 		    }
 
 		    // Create return value
-		    $returnValue = array();		    
+		    $returnValue = array();		
 		    foreach ($entries as $entry) {
 		        $tableName = $entry->xpath('.//m:properties/d:TableName');
 		        $tableName = (string)$tableName[0];
-		        
+		
 		        $returnValue[] = new Zend_Service_WindowsAzure_Storage_TableInstance(
 		            (string)$entry->id,
 		            $tableName,
@@ -184,9 +185,9 @@ class Zend_Service_WindowsAzure_Storage_Table
 		            (string)$entry->updated
 		        );
 		    }
-		    
+		
 			// More tables?
-		    if (!is_null($response->getHeader('x-ms-continuation-NextTableName'))) {
+		    if ($response->getHeader('x-ms-continuation-NextTableName') !== null) {
 		        $returnValue = array_merge($returnValue, $this->listTables($response->getHeader('x-ms-continuation-NextTableName')));
 		    }
 
@@ -212,9 +213,9 @@ class Zend_Service_WindowsAzure_Storage_Table
 		// Generate request body
 		$requestBody = '<?xml version="1.0" encoding="utf-8" standalone="yes"?>
                         <entry
-                        	xmlns:d="http://schemas.microsoft.com/ado/2007/08/dataservices"
-                        	xmlns:m="http://schemas.microsoft.com/ado/2007/08/dataservices/metadata"
-                        	xmlns="http://www.w3.org/2005/Atom">
+                            xmlns:d="http://schemas.microsoft.com/ado/2007/08/dataservices"
+                            xmlns:m="http://schemas.microsoft.com/ado/2007/08/dataservices/metadata"
+                            xmlns="http://www.w3.org/2005/Atom">
                           <title />
                           <updated>{tpl:Updated}</updated>
                           <author>
@@ -227,29 +228,29 @@ class Zend_Service_WindowsAzure_Storage_Table
                             </m:properties>
                           </content>
                         </entry>';
-		
+        
         $requestBody = $this->_fillTemplate($requestBody, array(
             'BaseUrl' => $this->getBaseUrl(),
             'TableName' => htmlspecialchars($tableName),
-        	'Updated' => $this->isoDate(),
+            'Updated' => $this->isoDate(),
             'AccountName' => $this->_accountName
         ));
-        
+
         // Add header information
         $headers = array();
         $headers['Content-Type'] = 'application/atom+xml';
         $headers['DataServiceVersion'] = '1.0;NetFx';
-        $headers['MaxDataServiceVersion'] = '1.0;NetFx';        
+        $headers['MaxDataServiceVersion'] = '1.0;NetFx';
 
 		// Perform request
 		$response = $this->_performRequest('Tables', '', Zend_Http_Client::POST, $headers, true, $requestBody);
 		if ($response->isSuccessful()) {
 		    // Parse response
 		    $entry = $this->_parseResponse($response);
-		    
+		
 		    $tableName = $entry->xpath('.//m:properties/d:TableName');
 		    $tableName = (string)$tableName[0];
-		        
+		
 		    return new Zend_Service_WindowsAzure_Storage_TableInstance(
 		        (string)$entry->id,
 		        $tableName,
@@ -286,7 +287,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Insert entity into table
-	 * 
+	 *
 	 * @param string                              $tableName   Table name
 	 * @param Zend_Service_WindowsAzure_Storage_TableEntity $entity      Entity to insert
 	 * @return Zend_Service_WindowsAzure_Storage_TableEntity
@@ -297,10 +298,10 @@ class Zend_Service_WindowsAzure_Storage_Table
 		if ($tableName === '') {
 			throw new Zend_Service_WindowsAzure_Exception('Table name is not specified.');
 		}
-		if (is_null($entity)) {
+		if ($entity === null) {
 			throw new Zend_Service_WindowsAzure_Exception('Entity is not specified.');
 		}
-		                     
+		
 		// Generate request body
 		$requestBody = '<?xml version="1.0" encoding="utf-8" standalone="yes"?>
                         <entry xmlns:d="http://schemas.microsoft.com/ado/2007/08/dataservices" xmlns:m="http://schemas.microsoft.com/ado/2007/08/dataservices/metadata" xmlns="http://www.w3.org/2005/Atom">
@@ -316,9 +317,9 @@ class Zend_Service_WindowsAzure_Storage_Table
                             </m:properties>
                           </content>
                         </entry>';
-		
+        
         $requestBody = $this->_fillTemplate($requestBody, array(
-        	'Updated'    => $this->isoDate(),
+            'Updated'    => $this->isoDate(),
             'Properties' => $this->_generateAzureRepresentation($entity)
         ));
 
@@ -337,13 +338,13 @@ class Zend_Service_WindowsAzure_Storage_Table
 		if ($response->isSuccessful()) {
 		    // Parse result
 		    $result = $this->_parseResponse($response);
-		    
+		
 		    $timestamp = $result->xpath('//m:properties/d:Timestamp');
 		    $timestamp = (string)$timestamp[0];
 
 		    $etag      = $result->attributes('http://schemas.microsoft.com/ado/2007/08/dataservices/metadata');
 		    $etag      = (string)$etag['etag'];
-		    
+		
 		    // Update properties
 		    $entity->setTimestamp($timestamp);
 		    $entity->setEtag($etag);
@@ -356,7 +357,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Delete entity from table
-	 * 
+	 *
 	 * @param string                              $tableName   Table name
 	 * @param Zend_Service_WindowsAzure_Storage_TableEntity $entity      Entity to delete
 	 * @param boolean                             $verifyEtag  Verify etag of the entity (used for concurrency)
@@ -367,14 +368,14 @@ class Zend_Service_WindowsAzure_Storage_Table
 		if ($tableName === '') {
 			throw new Zend_Service_WindowsAzure_Exception('Table name is not specified.');
 		}
-		if (is_null($entity)) {
+		if ($entity === null) {
 			throw new Zend_Service_WindowsAzure_Exception('Entity is not specified.');
 		}
-		                     
+		
         // Add header information
         $headers = array();
         if (!$this->isInBatch()) {
-        	// http://social.msdn.microsoft.com/Forums/en-US/windowsazure/thread/9e255447-4dc7-458a-99d3-bdc04bdc5474/
+            // http://social.msdn.microsoft.com/Forums/en-US/windowsazure/thread/9e255447-4dc7-458a-99d3-bdc04bdc5474/
             $headers['Content-Type']   = 'application/atom+xml';
         }
         $headers['Content-Length'] = 0;
@@ -399,11 +400,11 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Retrieve entity from table, by id
-	 * 
+	 *
 	 * @param string $tableName    Table name
 	 * @param string $partitionKey Partition key
 	 * @param string $rowKey       Row key
-	 * @param string $entityClass  Entity class name* 
+	 * @param string $entityClass  Entity class name*
 	 * @return Zend_Service_WindowsAzure_Storage_TableEntity
 	 * @throws Zend_Service_WindowsAzure_Exception
 	 */
@@ -430,7 +431,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 		    if ($this->isInBatch()) {
 		        throw new Zend_Service_WindowsAzure_Exception('Entity cannot be retrieved. A transaction is required to retrieve the entity, but another transaction is already active.');
 		    }
-		        
+		
 		    $this->startBatch();
 		}
 		
@@ -443,18 +444,18 @@ class Zend_Service_WindowsAzure_Storage_Table
             '',
             $entityClass
         );
-        
+
         // Return
         if (count($result) == 1) {
             return $result[0];
         }
-        
+
         return null;
 	}
 	
 	/**
 	 * Create a new Zend_Service_WindowsAzure_Storage_TableEntityQuery
-	 * 
+	 *
 	 * @return Zend_Service_WindowsAzure_Storage_TableEntityQuery
 	 */
 	public function select()
@@ -464,7 +465,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Retrieve entities from table
-	 * 
+	 *
 	 * @param string $tableName|Zend_Service_WindowsAzure_Storage_TableEntityQuery    Table name -or- Zend_Service_WindowsAzure_Storage_TableEntityQuery instance
 	 * @param string $filter                                                Filter condition (not applied when $tableName is a Zend_Service_WindowsAzure_Storage_TableEntityQuery instance)
 	 * @param string $entityClass                                           Entity class name
@@ -494,18 +495,18 @@ class Zend_Service_WindowsAzure_Storage_Table
 		// Determine query
 		if (is_string($tableName)) {
 		    // Option 1: $tableName is a string
-		    
+		
 		    // Append parentheses
 		    $tableName .= '()';
-		    
+		
     	    // Build query
     	    $query = array();
-    	    
+    	
     		// Filter?
     		if ($filter !== '') {
-    		    $query[] = '$filter=' . rawurlencode($filter);
+    		    $query[] = '$filter=' . Zend_Service_WindowsAzure_Storage_TableEntityQuery::encodeQuery($filter);
     		}
-    		    
+    		
     	    // Build queryString
     	    if (count($query) > 0)  {
     	        $queryString = '?' . implode('&', $query);
@@ -523,11 +524,11 @@ class Zend_Service_WindowsAzure_Storage_Table
 		}
 		
 		// Add continuation querystring parameters?
-		if (!is_null($nextPartitionKey) && !is_null($nextRowKey)) {
+		if ($nextPartitionKey !== null && $nextRowKey !== null) {
 		    if ($queryString !== '') {
 		        $queryString .= '&';
 		    }
-		        
+		
 		    $queryString .= '&NextPartitionKey=' . rawurlencode($nextPartitionKey) . '&NextRowKey=' . rawurlencode($nextRowKey);
 		}
 
@@ -536,7 +537,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	    if ($this->isInBatch() && $this->getCurrentBatch()->getOperationCount() == 0) {
 		    $this->getCurrentBatch()->enlistOperation($tableName, $queryString, Zend_Http_Client::GET, array(), true, null);
 		    $response = $this->getCurrentBatch()->commit();
-		    
+		
 		    // Get inner response (multipart)
 		    $innerResponse = $response->getBody();
 		    $innerResponse = substr($innerResponse, strpos($innerResponse, 'HTTP/1.1 200 OK'));
@@ -545,7 +546,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 		} else {
 		    $response = $this->_performRequest($tableName, $queryString, Zend_Http_Client::GET, array(), true, null);
 		}
-		
+
 		if ($response->isSuccessful()) {
 		    // Parse result
 		    $result = $this->_parseResponse($response);
@@ -571,19 +572,19 @@ class Zend_Service_WindowsAzure_Storage_Table
 		    }
 
 		    // Create return value
-		    $returnValue = array();		    
+		    $returnValue = array();		
 		    foreach ($entries as $entry) {
     		    // Parse properties
     		    $properties = $entry->xpath('.//m:properties');
     		    $properties = $properties[0]->children('http://schemas.microsoft.com/ado/2007/08/dataservices');
-    		    
+    		
     		    // Create entity
     		    $entity = new $entityClass('', '');
     		    $entity->setAzureValues((array)$properties, true);
-    		    
+    		
     		    // If we have a Zend_Service_WindowsAzure_Storage_DynamicTableEntity, make sure all property types are OK
     		    if ($entity instanceof Zend_Service_WindowsAzure_Storage_DynamicTableEntity) {
-    		        foreach ($properties as $key => $value) {  
+    		        foreach ($properties as $key => $value) {
     		            $attributes = $value->attributes('http://schemas.microsoft.com/ado/2007/08/dataservices/metadata');
     		            $type = (string)$attributes['type'];
     		            if ($type !== '') {
@@ -591,23 +592,23 @@ class Zend_Service_WindowsAzure_Storage_Table
     		            }
     		        }
     		    }
-    
+
     		    // Update etag
     		    $etag      = $entry->attributes('http://schemas.microsoft.com/ado/2007/08/dataservices/metadata');
     		    $etag      = (string)$etag['etag'];
     		    $entity->setEtag($etag);
-    		    
+    		
     		    // Add to result
     		    $returnValue[] = $entity;
 		    }
 
 			// More entities?
-		    if (!is_null($response->getHeader('x-ms-continuation-NextPartitionKey')) && !is_null($response->getHeader('x-ms-continuation-NextRowKey'))) {
+		    if ($response->getHeader('x-ms-continuation-NextPartitionKey') !== null && $response->getHeader('x-ms-continuation-NextRowKey') !== null) {
 		        if (strpos($queryString, '$top') === false) {
 		            $returnValue = array_merge($returnValue, $this->retrieveEntities($tableName, $filter, $entityClass, $response->getHeader('x-ms-continuation-NextPartitionKey'), $response->getHeader('x-ms-continuation-NextRowKey')));
 		        }
 		    }
-		    
+		
 		    // Return
 		    return $returnValue;
 		} else {
@@ -617,7 +618,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Update entity by replacing it
-	 * 
+	 *
 	 * @param string                              $tableName   Table name
 	 * @param Zend_Service_WindowsAzure_Storage_TableEntity $entity      Entity to update
 	 * @param boolean                             $verifyEtag  Verify etag of the entity (used for concurrency)
@@ -630,7 +631,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Update entity by adding or updating properties
-	 * 
+	 *
 	 * @param string                              $tableName   Table name
 	 * @param Zend_Service_WindowsAzure_Storage_TableEntity $entity      Entity to update
 	 * @param boolean                             $verifyEtag  Verify etag of the entity (used for concurrency)
@@ -654,13 +655,16 @@ class Zend_Service_WindowsAzure_Storage_Table
 		} else {
 			$mergeEntity = $entity;
 		}
+
+        // Ensure entity timestamp matches updated timestamp
+        $entity->setTimestamp($this->isoDate());
 		
 	    return $this->_changeEntity(Zend_Http_Client::MERGE, $tableName, $mergeEntity, $verifyEtag);
 	}
 	
 	/**
 	 * Get error message from Zend_Http_Response
-	 * 
+	 *
 	 * @param Zend_Http_Response $response Repsonse
 	 * @param string $alternativeError Alternative error message
 	 * @return string
@@ -677,7 +681,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Update entity / merge entity
-	 * 
+	 *
 	 * @param string                              $httpVerb    HTTP verb to use (PUT = update, MERGE = merge)
 	 * @param string                              $tableName   Table name
 	 * @param Zend_Service_WindowsAzure_Storage_TableEntity $entity      Entity to update
@@ -689,10 +693,10 @@ class Zend_Service_WindowsAzure_Storage_Table
 		if ($tableName === '') {
 			throw new Zend_Service_WindowsAzure_Exception('Table name is not specified.');
 		}
-		if (is_null($entity)) {
+		if ($entity === null) {
 			throw new Zend_Service_WindowsAzure_Exception('Entity is not specified.');
 		}
-		                     
+		
         // Add header information
         $headers = array();
         $headers['Content-Type']   = 'application/atom+xml';
@@ -703,8 +707,8 @@ class Zend_Service_WindowsAzure_Storage_Table
             $headers['If-Match']       = $entity->getEtag();
         }
 
-	    // Generate request body
-		$requestBody = '<?xml version="1.0" encoding="utf-8" standalone="yes"?>
+        // Generate request body
+        $requestBody = '<?xml version="1.0" encoding="utf-8" standalone="yes"?>
                         <entry xmlns:d="http://schemas.microsoft.com/ado/2007/08/dataservices" xmlns:m="http://schemas.microsoft.com/ado/2007/08/dataservices/metadata" xmlns="http://www.w3.org/2005/Atom">
                           <title />
                           <updated>{tpl:Updated}</updated>
@@ -718,28 +722,34 @@ class Zend_Service_WindowsAzure_Storage_Table
                             </m:properties>
                           </content>
                         </entry>';
-		
+        
+        // Attempt to get timestamp from entity
+        $timestamp = $entity->getTimestamp();
+        if ($timestamp == Zend_Service_WindowsAzure_Storage_TableEntity::DEFAULT_TIMESTAMP) {
+            $timestamp = $this->isoDate();
+        }
+
         $requestBody = $this->_fillTemplate($requestBody, array(
-        	'Updated'    => $this->isoDate(),
+            'Updated'    => $timestamp,
             'Properties' => $this->_generateAzureRepresentation($entity)
         ));
 
         // Add header information
         $headers = array();
         $headers['Content-Type'] = 'application/atom+xml';
-	    if (!$verifyEtag) {
+        if (!$verifyEtag) {
             $headers['If-Match']       = '*';
         } else {
             $headers['If-Match']       = $entity->getEtag();
         }
-        
+
 		// Perform request
 		$response = null;
 	    if ($this->isInBatch()) {
-		    $this->getCurrentBatch()->enlistOperation($tableName . '(PartitionKey=\'' . $entity->getPartitionKey() . '\', RowKey=\'' . $entity->getRowKey() . '\')', '', $httpVerb, $headers, true, $requestBody);
+		    $this->getCurrentBatch()->enlistOperation($tableName . '(PartitionKey=\'' . $entity->getPartitionKey() . '\',RowKey=\'' . $entity->getRowKey() . '\')', '', $httpVerb, $headers, true, $requestBody);
 		    return null;
 		} else {
-		    $response = $this->_performRequest($tableName . '(PartitionKey=\'' . $entity->getPartitionKey() . '\', RowKey=\'' . $entity->getRowKey() . '\')', '', $httpVerb, $headers, true, $requestBody);
+		    $response = $this->_performRequest($tableName . '(PartitionKey=\'' . $entity->getPartitionKey() . '\',RowKey=\'' . $entity->getRowKey() . '\')', '', $httpVerb, $headers, true, $requestBody);
 		}
 		if ($response->isSuccessful()) {
 		    // Update properties
@@ -754,7 +764,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Generate RFC 1123 compliant date string
-	 * 
+	 *
 	 * @return string
 	 */
 	protected function _rfcDate()
@@ -764,7 +774,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Fill text template with variables from key/value array
-	 * 
+	 *
 	 * @param string $templateText Template text
 	 * @param array $variables Array containing key/value pairs
 	 * @return string
@@ -779,7 +789,7 @@ class Zend_Service_WindowsAzure_Storage_Table
 	
 	/**
 	 * Generate Azure representation from entity (creates atompub markup from properties)
-	 * 
+	 *
 	 * @param Zend_Service_WindowsAzure_Storage_TableEntity $entity
 	 * @return string
 	 */
@@ -794,23 +804,63 @@ class Zend_Service_WindowsAzure_Storage_Table
 		    if ($azureValue->Type != '') {
 		        $value[] = ' m:type="' . $azureValue->Type . '"';
 		    }
-		    if (is_null($azureValue->Value)) {
-		        $value[] = ' m:null="true"'; 
+		    if ($azureValue->Value === null) {
+		        $value[] = ' m:null="true"';
 		    }
 		    $value[] = '>';
-		    
-		    if (!is_null($azureValue->Value)) {
+		
+		    if ($azureValue->Value !== null) {
 		        if (strtolower($azureValue->Type) == 'edm.boolean') {
 		            $value[] = ($azureValue->Value == true ? '1' : '0');
 		        } else {
 		            $value[] = htmlspecialchars($azureValue->Value);
 		        }
 		    }
-		    
+		
 		    $value[] = '</d:' . $azureValue->Name . '>';
 		    $azureRepresentation[] = implode('', $value);
 		}
 
 		return implode('', $azureRepresentation);
 	}
+	
+		/**
+	 * Perform request using Zend_Http_Client channel
+	 *
+	 * @param string $path Path
+	 * @param string $queryString Query string
+	 * @param string $httpVerb HTTP verb the request will use
+	 * @param array $headers x-ms headers to add
+	 * @param boolean $forTableStorage Is the request for table storage?
+	 * @param mixed $rawData Optional RAW HTTP data to be sent over the wire
+	 * @param string $resourceType Resource type
+	 * @param string $requiredPermission Required permission
+	 * @return Zend_Http_Response
+	 */
+	protected function _performRequest(
+		$path = '/',
+		$queryString = '',
+		$httpVerb = Zend_Http_Client::GET,
+		$headers = array(),
+		$forTableStorage = false,
+		$rawData = null,
+		$resourceType = Zend_Service_WindowsAzure_Storage::RESOURCE_UNKNOWN,
+		$requiredPermission = Zend_Service_WindowsAzure_Credentials_CredentialsAbstract::PERMISSION_READ
+	) {
+		// Add headers
+		$headers['DataServiceVersion'] = '1.0;NetFx';
+		$headers['MaxDataServiceVersion'] = '1.0;NetFx';
+
+		// Perform request
+		return parent::_performRequest(
+			$path,
+			$queryString,
+			$httpVerb,
+			$headers,
+			$forTableStorage,
+			$rawData,
+			$resourceType,
+			$requiredPermission
+		);
+	}
 }
