@@ -33,7 +33,7 @@ require_once 'Zend/Server/Interface.php';
  * @uses       Zend_Server_Interface
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Server.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: Server.php 24066 2011-05-28 19:42:53Z ralph $
  */
 class Zend_Soap_Server implements Zend_Server_Interface
 {
@@ -829,7 +829,7 @@ class Zend_Soap_Server implements Zend_Server_Interface
             $soap->fault("Sender", $setRequestException->getMessage());
         } else {
             try {
-                $soap->handle($request);
+                $soap->handle($this->_request);
             } catch (Exception $e) {
                 $fault = $this->fault($e);
                 $soap->fault($fault->faultcode, $fault->faultstring);
