@@ -203,7 +203,7 @@ class Zend_Application_Resource_MailTest extends PHPUnit_Framework_TestCase
     /**
      * @group ZF-9136
      */
-    public function testCustomMailTransportWithWrontCasesAsShouldBe() {
+    public function testCustomMailTransportWithWrongCasesAsShouldBe() {
         $options = array('transport' => array('type' => 'Zend_Application_Resource_mailTestCAsE'));
         $resource = new Zend_Application_Resource_Mail(array());
         $resource->setBootstrap($this->bootstrap);
@@ -211,6 +211,22 @@ class Zend_Application_Resource_MailTest extends PHPUnit_Framework_TestCase
 
         $this->assertTrue($resource->init() instanceof Zend_Application_Resource_mailTestCAsE);
     }
+    
+    /**
+     * @group ZF-11022
+     */
+    public function testOptionRegisterIsUnset()
+    {
+        $options = array('transport' => 
+                        array('register' => 1,
+                              'type' => 'Zend_Mail_Transport_Sendmail'));
+
+        $resource = new Zend_Application_Resource_Mail(array());
+        $resource->setBootstrap($this->bootstrap);
+        $resource->setOptions($options);
+
+        $this->assertEmpty($resource->getMail()->parameters);
+    }
 
 }
 
