@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: NavigationTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: NavigationTest.php 24340 2011-08-02 18:28:17Z matthew $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -67,6 +67,8 @@ class Zend_Application_Resource_NavigationTest extends PHPUnit_Framework_TestCas
 
     public function tearDown()
     {
+        Zend_Navigation_Page::setDefaultPageType();
+
         // Restore original autoloaders
         $loaders = spl_autoload_functions();
         foreach ($loaders as $loader) {
@@ -93,7 +95,7 @@ class Zend_Application_Resource_NavigationTest extends PHPUnit_Framework_TestCas
 
     public function testInitializationReturnsNavigationObject()
     {
-           $this->bootstrap->registerPluginResource('view');
+        $this->bootstrap->registerPluginResource('view');
         $resource = new Zend_Application_Resource_Navigation(array());
         $resource->setBootstrap($this->bootstrap);
         $test = $resource->init();
@@ -149,6 +151,32 @@ class Zend_Application_Resource_NavigationTest extends PHPUnit_Framework_TestCas
          $this->assertEquals($view->setInMethodByTest,true);
     }
 
+    /**
+     * @group ZF-10959
+     */
+    public function testDefaultPageTypeIsSet()
+    {
+        $this->bootstrap->registerPluginResource('view');
+        $this->bootstrap->getPluginResource('view')->getView();
+
+        $options = array('defaultPageType' => 'foobar',
+                         'pages'=> array(array(
+            			 'action'     => 'index',
+                         'controller' => 'index')));
+
+        $results = array();
+        $resource = new Zend_Application_Resource_Navigation($options);
+
+        try {
+            $resource->setBootstrap($this->bootstrap)->init();
+            $this->fail('An exception should have been thrown but wasn\'t');
+        } catch(Zend_Exception $e) {
+            $this->assertTrue(true);
+        }
+
+        $this->bootstrap->unregisterPluginResource('view');
+    }
+
     /**
      * @group ZF-7461
      */
