@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IniTest.php 22869 2010-08-21 13:57:59Z ramon $
+ * @version    $Id: IniTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * Zend_Config
  */
@@ -44,7 +39,7 @@ require_once 'Zend/Config/Writer/Ini.php';
  * @category   Zend
  * @package    Zend_Config
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Config
  */
@@ -246,7 +241,7 @@ ECS;
             $this->assertContains('Value can not contain double quotes "', $expected->getMessage());
         }
     }
-    
+
     /**
      * @group ZF-6289
      */
@@ -259,10 +254,10 @@ ECS;
             'four'  => array('type' => 'section'),
             'five'  => 'element'
         ));
-        
+
         $writer = new Zend_Config_Writer_Ini;
         $iniString = $writer->setConfig($config)->render($config);
-        
+
         $expected = <<<ECS
 one = "element"
 three = "element"
@@ -275,7 +270,7 @@ type = "section"
 
 
 ECS;
-        
+
         $this->assertEquals(
             $expected,
             $iniString
