@@ -15,31 +15,21 @@
  * @category   Zend
  * @package    Zend_Console_Getop
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: GetoptTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: GetoptTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * Zend_Console_Getopt
  */
 require_once 'Zend/Console/Getopt.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
 /**
  * @category   Zend
  * @package    Zend_Console_Getopt
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Console_Getopt
  */
@@ -278,7 +268,7 @@ class Zend_Console_GetoptTest extends PHPUnit_Framework_TestCase
         unset($opts->a);
         $this->assertFalse(isset($opts->a));
     }
-    
+
     /**
      * @group ZF-5948
      */
@@ -294,7 +284,7 @@ class Zend_Console_GetoptTest extends PHPUnit_Framework_TestCase
             $this->assertEquals("Parameter #1 to setArguments should be an array",
                 $e->getMessage());
         }
-        
+
         try {
             $opts->addArguments('-b');
             $this->fail('Expected to catch a Zend_Console_Getopt_Exception');
@@ -304,7 +294,7 @@ class Zend_Console_GetoptTest extends PHPUnit_Framework_TestCase
             $this->assertEquals("Parameter #1 to addArguments should be an array",
                 $e->getMessage());
         }
-        
+
     }
 
     public function testGetoptAddArguments()
