@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FrontTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: FrontTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Controller_FrontTest::main() if this source file is executed directly.
@@ -33,8 +33,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     );
 }
 
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
 
 require_once 'Zend/Controller/Front.php';
 require_once 'Zend/Controller/Request/Http.php';
@@ -49,7 +47,7 @@ require_once 'Zend/Controller/Action/Helper/ViewRenderer.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Front
@@ -66,7 +64,6 @@ class Zend_Controller_FrontTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_FrontTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
