@@ -15,23 +15,24 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ChainTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ChainTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Controller_Router_Route_ChainTest::main');
 }
 
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 /** Zend_Config */
 require_once 'Zend/Config.php';
 
 /** Zend_Controller_Router_Rewrite */
 require_once 'Zend/Controller/Router/Rewrite.php';
 
+/** Zend_Controller_Dispatcher_Standard */
+require_once 'Zend/Controller/Dispatcher/Standard.php';
+
 /** Zend_Controller_Router_Route_Chain */
 require_once 'Zend/Controller/Router/Route/Chain.php';
 
@@ -63,7 +64,7 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Router
@@ -78,7 +79,6 @@ class Zend_Controller_Router_Route_ChainTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_Router_Route_ChainTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -116,6 +116,31 @@ class Zend_Controller_Router_Route_ChainTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(2, $res['bar']);
     }
 
+    /**
+     * @group ZF-8812
+     */
+    public function testChainingMatchToDefaultValues()
+    {
+        $foo = new Zend_Controller_Router_Route(
+            ':foo',
+            array('foo' => 'bar'),
+            array('foo' => '[a-z]{3}')
+        );
+
+        $bar = new Zend_Controller_Router_Route_Module(array(
+            'module' => 0,
+            'controller' => 1,
+            'action' => 2
+        ));
+
+        $chain = $foo->chain($bar);
+
+        $request = new Zend_Controller_Router_ChainTest_Request('http://www.zend.com/');
+        $res = $chain->match($request);
+
+        $this->assertTrue(is_array($res), 'Route did not match to default values.');
+    }
+
     public function testChainingShortcutMatch()
     {
         $foo = new Zend_Controller_Router_Route_Hostname('www.zend.com', array('foo' => 1));
@@ -426,8 +451,8 @@ class Zend_Controller_Router_Route_ChainTest extends PHPUnit_Framework_TestCase
         $router = new Zend_Controller_Router_Rewrite();
         $front = Zend_Controller_Front::getInstance();
         $front->resetInstance();
-        $front->setDispatcher(new Zend_Controller_Router_RewriteTest_Dispatcher());
-        $front->setRequest(new Zend_Controller_Router_RewriteTest_Request());
+        $front->setDispatcher(new Zend_Controller_Router_ChainTest_Dispatcher());
+        $front->setRequest(new Zend_Controller_Router_ChainTest_Request());
         $router->setFrontController($front);
 
         $router->addConfig(new Zend_Config($routes));
@@ -640,7 +665,156 @@ class Zend_Controller_Router_Route_ChainTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('foo', $res['controller']);
         $this->assertEquals('bar', $res['action']);
     }
-    
+
+    /**
+     * @group ZF-7848
+     */
+    public function testChainingWithEmptyStaticRoutesMatchesCorrectly()
+    {
+        $adminRoute = new Zend_Controller_Router_Route('admin', array(
+            'module'     => 'admin',
+            'controller' => 'index',
+            'action'     => 'index',
+        ));
+        $indexRoute = new Zend_Controller_Router_Route_Static('', array(
+            'module'     => 'admin',
+            'controller' => 'index',
+            'action'     => 'index',
+        ));
+        $loginRoute = new Zend_Controller_Router_Route('login', array(
+            'module'     => 'admin',
+            'controller' => 'login',
+            'action'     => 'index',
+        ));
+        $emptyRoute    = $adminRoute->chain($indexRoute);
+        $nonEmptyRoute = $adminRoute->chain($loginRoute);
+
+        $request = new Zend_Controller_Request_Http();
+        $request->setPathInfo('/admin');
+        $values = $emptyRoute->match($request);
+        $this->assertEquals(array(
+            'module'     => 'admin',
+            'controller' => 'index',
+            'action'     => 'index',
+        ), $values);
+
+        $request->setPathInfo('/admin/');
+        $values = $emptyRoute->match($request);
+        $this->assertEquals(array(
+            'module'     => 'admin',
+            'controller' => 'index',
+            'action'     => 'index',
+        ), $values);
+
+        $request->setPathInfo('/admin/login');
+        $values = $nonEmptyRoute->match($request);
+        $this->assertEquals(array(
+            'module'     => 'admin',
+            'controller' => 'login',
+            'action'     => 'index',
+        ), $values);
+    }
+
+    /**
+     * @group ZF-7848
+     */
+    public function testChainingWithConfiguredEmptyStaticRoutesMatchesCorrectly()
+    {
+        $routes = array(
+            'admin' => array(
+                'route' => 'admin',
+                'defaults' => array(
+                    'module'     => 'admin',
+                    'controller' => 'index',
+                    'action'     => 'index',
+                ),
+                'chains' => array(
+                    'index' => array(
+                        'type'  => 'Zend_Controller_Router_Route_Static',
+                        'route' => '',
+                        'defaults' => array(
+                            'module'     => 'admin',
+                            'controller' => 'index',
+                            'action'     => 'index',
+                        ),
+                    ),
+                    'login' => array(
+                        'route' => 'login',
+                        'defaults' => array(
+                            'module'     => 'admin',
+                            'controller' => 'login',
+                            'action'     => 'index',
+                        ),
+                    ),
+
+                ),
+            ),
+        );
+        $config = new Zend_Config($routes);
+        $rewrite = new Zend_Controller_Router_Rewrite();
+        $rewrite->addConfig($config);
+        $routes = $rewrite->getRoutes();
+        $indexRoute = $rewrite->getRoute('admin-index');
+        $loginRoute = $rewrite->getRoute('admin-login');
+
+        $request = new Zend_Controller_Request_Http();
+        $request->setPathInfo('/admin');
+        $values = $indexRoute->match($request);
+        $this->assertEquals(array(
+            'module'     => 'admin',
+            'controller' => 'index',
+            'action'     => 'index',
+        ), $values);
+
+        $request->setPathInfo('/admin/');
+        $values = $indexRoute->match($request);
+        $this->assertEquals(array(
+            'module'     => 'admin',
+            'controller' => 'index',
+            'action'     => 'index',
+        ), $values);
+
+        $request->setPathInfo('/admin/login');
+        $values = $loginRoute->match($request);
+        $this->assertEquals(array(
+            'module'     => 'admin',
+            'controller' => 'login',
+            'action'     => 'index',
+        ), $values);
+    }
+
+    /**
+     * @group ZF-7368
+     */
+    public function testChainingStaticDynamicMatchToDefaults()
+    {
+        $foo = new Zend_Controller_Router_Route_Static('foo');
+        $bar = new Zend_Controller_Router_Route(':bar', array('bar' => 0));
+        $chain = $foo->chain($bar);
+
+        $request = new Zend_Controller_Router_ChainTest_Request('http://www.zend.com/foo');
+        $res = $chain->match($request);
+
+        $this->assertType('array', $res, 'Route did not match');
+        $this->assertEquals(0, $res['bar']);
+    }
+
+    /**
+     * @group ZF-7368
+     */
+    public function testChainingStaticDynamicMatchToParams()
+    {
+        $foo = new Zend_Controller_Router_Route_Static('foo');
+        $bar = new Zend_Controller_Router_Route(':bar', array('bar' => 1));
+        $chain = $foo->chain($bar);
+
+        $request = new Zend_Controller_Router_ChainTest_Request('http://www.zend.com/foo/2');
+        $res = $chain->match($request);
+
+        $this->assertType('array', $res, 'Route did not match');
+        $this->assertEquals(2, $res['bar']);
+    }
+
     protected function _getRouter()
     {
         $router = new Zend_Controller_Router_Rewrite();
@@ -683,6 +857,22 @@ class Zend_Controller_Router_ChainTest_Request extends Zend_Controller_Request_H
     }
 }
 
+/**
+ * Zend_Controller_Router_ChainTest_Dispatcher - dispatcher object for router testing
+ */
+class Zend_Controller_Router_ChainTest_Dispatcher extends Zend_Controller_Dispatcher_Standard
+{
+    public function getDefaultControllerName()
+    {
+        return 'defctrl';
+    }
+
+    public function getDefaultAction()
+    {
+        return 'defact';
+    }
+}
+
 if (PHPUnit_MAIN_METHOD == "Zend_Controller_Router_Route_ChainTest::main") {
     Zend_Controller_Router_Route_ChainTest::main();
 }
