@@ -15,23 +15,17 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: HostnameTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: HostnameTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/** Test helper */
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 /** Zend_Controller_Router_Route_Hostname */
 require_once 'Zend/Controller/Router/Route/Hostname.php';
 
 /** Zend_Controller_Request_Http */
 require_once 'Zend/Controller/Request/Http.php';
 
-/** PHPUnit test case */
-require_once 'PHPUnit/Framework/TestCase.php';
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Controller_Router_Route_HostnameTest::main');
 }
@@ -40,7 +34,7 @@ if (!defined('PHPUnit_MAIN_METHOD')) {
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Router
@@ -55,7 +49,6 @@ class Zend_Controller_Router_Route_HostnameTest extends PHPUnit_Framework_TestCa
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Controller_Router_Route_HostnameTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
