@@ -15,13 +15,11 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RegexTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: RegexTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 /** Zend_Controller_Router_Route_Regex */
 require_once 'Zend/Controller/Router/Route/Regex.php';
 
@@ -29,7 +27,7 @@ require_once 'Zend/Controller/Router/Route/Regex.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Router
@@ -410,7 +408,7 @@ class Zend_Controller_Router_Route_RegexTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @issue ZF-2301
+     * @group ZF-2301
      */
     public function testAssemblyOfRouteWithMergedMatchedParts()
     {
