@@ -15,20 +15,14 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Static.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: Static.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 
-/**
- * PHPUnit_Util_Filter
- */
-require_once 'PHPUnit/Util/Filter.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
 
 /**
  * @see Zend_Db_Adapter_Abstract
@@ -48,7 +42,7 @@ require_once 'Zend/Db/Statement/Static.php';
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Db_Adapter_Static extends Zend_Db_Adapter_Abstract
@@ -288,7 +282,8 @@ class Zend_Db_Adapter_Static extends Zend_Db_Adapter_Abstract
      */
     public function setFetchMode($mode)
     {
-        return;
+        $this->_fetchMode = $mode;
+        return $this;
     }
 
     /**
