@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StaticTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: StaticTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 
@@ -27,14 +27,11 @@
 require_once 'Zend/Db/TestSetup.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
-
-
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Db
  * @group      Zend_Db_Profiler
@@ -496,6 +493,8 @@ class Zend_Db_Profiler_StaticTest extends Zend_Db_TestSetup
         $this->assertEquals(count($queries), count($queryProfiles));
 
         foreach ($queryProfiles as $queryId => $queryProfile) {
+            $this->assertNotNull($queryProfile->getStartedMicrotime());
+
             $this->assertTrue(isset($queries[$queryId]));
             $this->assertEquals($queries[$queryId]['sql'], $queryProfile->getQuery());
             $this->assertEquals($queries[$queryId]['typeExpected'], $queryProfile->getQueryType());
