@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TestCommon.php 22616 2010-07-17 15:53:16Z ramon $
+ * @version    $Id: TestCommon.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 
@@ -27,14 +27,14 @@
 require_once 'Zend/Db/Table/TestSetup.php';
 
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
+
 
 
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Db
  * @group      Zend_Db_Table
@@ -291,4 +291,52 @@ abstract class Zend_Db_Table_Rowset_TestCommon extends Zend_Db_Table_TestSetup
         $this->assertEquals(0, $rowset->key());
     }
 
+
+
+    /**
+     * @group ZF-8486
+     */
+    public function testTableRowsetIteratesAndWillReturnLastRowAfter()
+    {
+        $table = $this->_table['bugs'];
+        $rowset = $table->fetchAll('bug_id IN (1,2,3,4)', 'bug_id ASC');
+        foreach ($rowset as $row) {
+            $lastRow = $row;
+        }
+
+        $numRows = $rowset->count();
+        $this->assertEquals(4, $numRows);
+
+        $rowset->seek(3);
+        $seekLastRow = $rowset->current();
+
+        $this->assertSame($lastRow, $seekLastRow);
+    }
+
+    /**
+     * @group ZF-8486
+     */
+    public function testTableRowsetThrowsExceptionOnInvalidSeek()
+    {
+        $table = $this->_table['bugs'];
+        $rowset = $table->fetchAll('bug_id IN (1,2,3,4)', 'bug_id ASC');
+        $rowset->seek(3);
+
+        $this->setExpectedException('Zend_Db_Table_Rowset_Exception', 'Illegal index 4');
+        $rowset->seek(4);
+    }
+
+    /**
+     * @group ZF-8486
+     */
+    public function testTableRowsetThrowsExceptionOnInvalidGetRow()
+    {
+        $table = $this->_table['bugs'];
+        $rowset = $table->fetchAll('bug_id IN (1,2,3,4)', 'bug_id ASC');
+        $rowset->getRow(3);
+
+        $this->setExpectedException('Zend_Db_Table_Rowset_Exception', 'No row could be found at position 4');
+        $rowset->getRow(4);
+    }
+
 }
