@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: EditorTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: EditorTest.php 23921 2011-05-02 19:11:31Z matthew $
  */
 
 // Call Zend_Dojo_Form_Element_EditorTest::main() if this source file is executed directly.
@@ -262,6 +262,35 @@ class Zend_Dojo_Form_Element_EditorTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($this->element->getDijitParam('updateInterval'), $this->element->getUpdateInterval());
         $this->assertEquals(300, $this->element->getUpdateInterval());
     }
+    
+    public function testCanAddMultipleSeparatorsToEditor()
+    {
+        $this->element->setPlugins(array('undo', '|', 'bold', '|', 'italic'));
+        
+        $plugins = $this->element->getPlugins();
+        $this->assertEquals(5, count($plugins));
+    }
+    
+    public function testMinHeightCanBeSetToPixels()
+    {
+        $this->element->setMinHeight('250px');
+        $this->assertEquals($this->element->getDijitParam('minHeight'), $this->element->getMinHeight());
+        $this->assertEquals('250px', $this->element->getMinHeight());
+    }
+    
+    public function testMinHeightCanBeSetToPercentage()
+    {
+        $this->element->setMinHeight('50%');
+        $this->assertEquals($this->element->getDijitParam('minHeight'), $this->element->getMinHeight());
+        $this->assertEquals('50%', $this->element->getMinHeight());
+    }
+    
+    public function testMinHeightDefaultMeasurementIsEm()
+    {
+        $this->element->setMinHeight('10');
+        $this->assertEquals($this->element->getDijitParam('minHeight'), $this->element->getMinHeight());
+        $this->assertEquals('10em', $this->element->getMinHeight());
+    }
 }
 
 // Call Zend_Dojo_Form_Element_EditorTest::main() if this source file is executed directly.
