@@ -15,13 +15,11 @@
  * @category   Zend
  * @package    Zend_Feed
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id$
  */
 
-require_once dirname(dirname(dirname(dirname(dirname(dirname(__FILE__)))))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
 require_once 'Zend/Feed/Writer/Renderer/Feed/Rss.php';
 require_once 'Zend/Feed/Reader.php';
 require_once 'Zend/Version.php';
@@ -32,7 +30,7 @@ require_once 'Zend/Version.php';
  * @subpackage UnitTests
  * @group      Zend_Feed
  * @group      Zend_Feed_Writer
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
@@ -46,7 +44,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $this->_validWriter->setTitle('This is a test feed.');
         $this->_validWriter->setDescription('This is a test description.');
         $this->_validWriter->setLink('http://www.example.com');
-        
+
         $this->_validWriter->setType('rss');
     }
 
@@ -96,7 +94,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('This is a test feed.', $feed->getTitle());
     }
-    
+
     /**
      * @expectedException Zend_Feed_Exception
      */
@@ -126,7 +124,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('This is a test description.', $feed->getDescription());
     }
-    
+
     /**
      * @expectedException Zend_Feed_Exception
      */
@@ -136,7 +134,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $this->_validWriter->remove('description');
         $rssFeed->render();
     }
-    
+
     /**
      * @group ZFWCHARDATA01
      */
@@ -157,7 +155,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals(1234567890, $feed->getDateModified()->get(Zend_Date::TIMESTAMP));
     }
-    
+
     public function testFeedUpdatedDateIfMissingThrowsNoException()
     {
         $rssFeed = new Zend_Feed_Writer_Renderer_Feed_Rss($this->_validWriter);
@@ -182,7 +180,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('FooFeedBuilder 1.00 (http://www.example.com)', $feed->getGenerator());
     }
-    
+
     public function testFeedGeneratorIfMissingThrowsNoException()
     {
         $rssFeed = new Zend_Feed_Writer_Renderer_Feed_Rss($this->_validWriter);
@@ -206,7 +204,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('fr', $feed->getLanguage());
     }
-    
+
     public function testFeedLanguageIfMissingThrowsNoException()
     {
         $rssFeed = new Zend_Feed_Writer_Renderer_Feed_Rss($this->_validWriter);
@@ -229,7 +227,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('http://www.example.com', $feed->getLink());
     }
-    
+
     /**
      * @expectedException Zend_Feed_Exception
      */
@@ -248,14 +246,14 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('http://www.example.com/rss', $feed->getFeedLink());
     }
-    
+
     public function testFeedLinkToXmlRssWhereTheFeedWillBeAvailableIfMissingThrowsNoException()
     {
         $rssFeed = new Zend_Feed_Writer_Renderer_Feed_Rss($this->_validWriter);
         $this->_validWriter->remove('feedLinks');
         $rssFeed->render();
     }
-    
+
     public function testBaseUrlCanBeSet()
     {
         $this->_validWriter->setBaseUrl('http://www.example.com/base');
@@ -264,7 +262,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('http://www.example.com/base', $feed->getBaseUrl());
     }
-    
+
     /**
      * @group ZFW003
      */
@@ -277,12 +275,12 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $author = $feed->getAuthor();
         $this->assertEquals(array('name'=>'Joe'), $feed->getAuthor());
     }
-    
+
     /**
      * @group ZFWCHARDATA01
      */
     public function testFeedAuthorCharDataEncoding()
-    {   
+    {
         $this->_validWriter->addAuthor('<>&\'"áéíóú', 'joe@example.com', 'http://www.example.com/joe');
         $atomFeed = new Zend_Feed_Writer_Renderer_Feed_Rss($this->_validWriter);
         $atomFeed->render();
@@ -290,7 +288,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $author = $feed->getAuthor();
         $this->assertEquals(array('name'=>'<>&\'"áéíóú'), $feed->getAuthor());
     }
-    
+
     public function testCopyrightCanBeSet()
     {
         $this->_validWriter->setCopyright('Copyright © 2009 Paddy');
@@ -299,7 +297,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('Copyright © 2009 Paddy', $feed->getCopyright());
     }
-    
+
     /**
      * @group ZFWCHARDATA01
      */
@@ -311,7 +309,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $feed = Zend_Feed_Reader::importString($rssFeed->saveXml());
         $this->assertEquals('<>&\'"áéíóú', $feed->getCopyright());
     }
-    
+
     public function testCategoriesCanBeSet()
     {
         $this->_validWriter->addCategories(array(
@@ -327,7 +325,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         );
         $this->assertEquals($expected, (array) $feed->getCategories());
     }
-    
+
     /**
      * @group ZFWCHARDATA01
      */
@@ -346,7 +344,7 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         );
         $this->assertEquals($expected, (array) $feed->getCategories());
     }
-    
+
     public function testHubsCanBeSet()
     {
         $this->_validWriter->addHubs(
@@ -380,9 +378,9 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
             'title' => 'Image ALT',
             'height' => '400',
             'width' => '144',
-            'description' => 'Image TITLE'  
+            'description' => 'Image TITLE'
         );
-        $this->assertEquals($expected, $feed->getImage()); 
+        $this->assertEquals($expected, $feed->getImage());
     }
 
     public function testImageCanBeSetWithOnlyRequiredElements()
@@ -398,9 +396,9 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $expected = array(
             'uri' => 'http://www.example.com/logo.gif',
             'link' => 'http://www.example.com',
-            'title' => 'Image ALT' 
+            'title' => 'Image ALT'
         );
-        $this->assertEquals($expected, $feed->getImage()); 
+        $this->assertEquals($expected, $feed->getImage());
     }
 
     /**
@@ -567,6 +565,6 @@ class Zend_Feed_Writer_Renderer_Feed_RssTest extends PHPUnit_Framework_TestCase
         $rssFeed = new Zend_Feed_Writer_Renderer_Feed_Rss($this->_validWriter);
         $rssFeed->render();
     }
-    
+
 
 }
