@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StringTrimTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: StringTrimTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Filter_StringTrim
  */
@@ -34,7 +29,7 @@ require_once 'Zend/Filter/StringTrim.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Filter
  */
@@ -120,4 +115,22 @@ class Zend_Filter_StringTrimTest extends PHPUnit_Framework_TestCase
     public function testZF7902()
     {
         $this->assertEquals('/', $this->_filter->filter('/'));
-    }}
+    }
+
+    /**
+     * @group ZF-10691
+     */
+    public function testSetParamCharListToConstructor()
+    {
+        require_once 'Zend/Config.php';
+        $config = new Zend_Config(array('charlist' => '&'));
+        $filter = new Zend_Filter_StringTrim($config);
+        $this->assertEquals('&', $filter->getCharList());
+
+        $filter = new Zend_Filter_StringTrim(array('charlist' => '&'));
+        $this->assertEquals('&', $filter->getCharList());
+
+        $filter = new Zend_Filter_StringTrim('&');
+        $this->assertEquals('&', $filter->getCharList());
+    }
+}
