@@ -15,19 +15,16 @@
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: UnderscoreToCamelCaseTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: UnderscoreToCamelCaseTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Filter_Word_UnderscoreToCamelCaseTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
-    require_once dirname(dirname(dirname(__FILE__))) . '/TestHelper.php';
     define("PHPUnit_MAIN_METHOD", "Zend_Filter_Word_UnderscoreToCamelCaseTest::main");
 }
 
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
 
 require_once 'Zend/Filter/Word/UnderscoreToCamelCase.php';
 
@@ -37,7 +34,7 @@ require_once 'Zend/Filter/Word/UnderscoreToCamelCase.php';
  * @category   Zend
  * @package    Zend_Filter
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Filter
  */
@@ -51,7 +48,6 @@ class Zend_Filter_Word_UnderscoreToCamelCaseTest extends PHPUnit_Framework_TestC
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Filter_Word_UnderscoreToCamelCaseTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
