@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FormErrorsTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: FormErrorsTest.php 23853 2011-04-10 16:06:30Z ramon $
  */
 
 // Call Zend_Form_Decorator_FormErrorsTest::main() if this source file is executed directly.
@@ -318,6 +318,17 @@ class Zend_Form_Decorator_FormErrorsTest extends PHPUnit_Framework_TestCase
         }
     }
 
+    /**
+     * @group ZF-11151
+     */
+    public function testOptionShowCustomFormErrors()
+    {
+        $this->decorator
+             ->setOption('showCustomFormErrors', true);
+
+        $this->assertTrue($this->decorator->getShowCustomFormErrors());
+    }
+
     public function markupOptionMethodsProvider()
     {
         return array(
