@@ -15,17 +15,15 @@
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: DisplayGroupTest.php 22465 2010-06-19 17:41:03Z alab $
+ * @version    $Id: DisplayGroupTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Form_DisplayGroupTest::main');
 }
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 require_once 'Zend/Form/DisplayGroup.php';
 
 require_once 'Zend/Config.php';
@@ -44,7 +42,7 @@ require_once 'Zend/View.php';
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Form
  */
@@ -314,7 +312,7 @@ class Zend_Form_DisplayGroupTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3069
+     * @group ZF-3069
      */
     public function testRemovingNamedDecoratorsShouldWork()
     {
@@ -362,7 +360,7 @@ class Zend_Form_DisplayGroupTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3494
+     * @group ZF-3494
      */
     public function testGetViewShouldNotReturnNullWhenViewRendererIsActive()
     {
