@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ButtonTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ButtonTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Form_Element_ButtonTest::main() if this source file is executed directly.
@@ -25,8 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Form_Element_ButtonTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 require_once 'Zend/Form/Element/Button.php';
 require_once 'Zend/Translate.php';
 
@@ -36,7 +34,7 @@ require_once 'Zend/Translate.php';
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Form
  */
@@ -49,7 +47,6 @@ class Zend_Form_Element_ButtonTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Form_Element_ButtonTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -147,7 +144,7 @@ class Zend_Form_Element_ButtonTest extends PHPUnit_Framework_TestCase
         $this->assertContains('Button Label', $html, $html);
         $this->assertNotContains('value="', $html);
     }
-    
+
     public function testSetDefaultIgnoredToTrueWhenNotDefined()
     {
         $this->assertTrue($this->element->getIgnore());
