@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MultiselectTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: MultiselectTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Form_Element_MultiselectTest::main() if this source file is executed directly.
@@ -25,7 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Form_Element_MultiselectTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
 
 require_once 'Zend/Form/Element/Multiselect.php';
 require_once 'Zend/Translate.php';
@@ -36,7 +35,7 @@ require_once 'Zend/Translate.php';
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Form
  */
@@ -152,7 +151,7 @@ class Zend_Form_Element_MultiselectTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2824
+     * @group ZF-2824
      */
     public function testCanSetMultiOptionsUsingAssocArraysWithKeyValueKeys()
     {
@@ -177,7 +176,7 @@ class Zend_Form_Element_MultiselectTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2824
+     * @group ZF-2824
      */
     public function testCanSetMultiOptionsUsingConfigWithKeyValueKeys()
     {
