@@ -15,19 +15,15 @@
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ElementTest.php 22465 2010-06-19 17:41:03Z alab $
+ * @version    $Id: ElementTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Form_ElementTest::main');
 }
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-// error_reporting(E_ALL);
-
 require_once 'Zend/Form/Element.php';
 
 require_once 'Zend/Config.php';
@@ -46,7 +42,7 @@ require_once 'Zend/View.php';
  * @category   Zend
  * @package    Zend_Form
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Form
  */
@@ -184,7 +180,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2851
+     * @group ZF-2851
      */
     public function testSetNameShouldNotAllowEmptyString()
     {
@@ -315,7 +311,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2862
+     * @group ZF-2862
      */
     public function testBreakChainOnFailureFlagsForExistingValidatorsRemainSetWhenNotEmptyValidatorAutoInserted()
     {
@@ -850,7 +846,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**#@+
-     * @see ZF-2988
+     * @group ZF-2988
      */
     public function testSettingErrorMessageShouldOverrideValidationErrorMessages()
     {
@@ -1387,7 +1383,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3597
+     * @group ZF-3597
      */
     public function testAddingConcreteDecoratorShouldHonorOrder()
     {
@@ -1451,7 +1447,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3069
+     * @group ZF-3069
      */
     public function testRemovingNamedDecoratorsShouldWork()
     {
@@ -1518,7 +1514,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3376
+     * @group ZF-3376
      */
     public function testSetDecoratorsShouldAcceptReturnOfGetDecorators()
     {
@@ -2049,7 +2045,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(1, count($messages));
         $this->assertEquals('foo', array_shift($messages));
     }
-    
+
     /**
      * @group ZF-9275
      */
@@ -2058,21 +2054,21 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $registryTranslations = array('alphaInvalid' => 'Registry message');
         $registryTranslate = new Zend_Translate('array', $registryTranslations);
         Zend_Registry::set('Zend_Translate', $registryTranslate);
-        
+
         $validatorTranslations = array('alphaInvalid' => 'Validator message');
         $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
         Zend_Validate_Abstract::setDefaultTranslator($validatorTranslate);
-        
+
         $elementTranslations = array('alphaInvalid' => 'Element message');
         $elementTranslate = new Zend_Translate('array', $elementTranslations);
-       
+
         // the default validate translator should beat the registry one
         $this->element->addValidator('Alpha');
         $this->assertFalse($this->element->isValid(123));
         $messages = $this->element->getMessages();
         $this->assertEquals('Validator message', $messages['alphaInvalid']);
     }
-    
+
     /**
      * @group ZF-9275
      */
@@ -2081,14 +2077,14 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $registryTranslations = array('alphaInvalid' => 'Registry message');
         $registryTranslate = new Zend_Translate('array', $registryTranslations);
         Zend_Registry::set('Zend_Translate', $registryTranslate);
-        
+
         $validatorTranslations = array('alphaInvalid' => 'Validator message');
         $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
         Zend_Validate_Abstract::setDefaultTranslator($validatorTranslate);
-        
+
         $elementTranslations = array('alphaInvalid' => 'Element message');
         $elementTranslate = new Zend_Translate('array', $elementTranslations);
-        
+
         $this->element->addValidator('Alpha');
         $this->element->setTranslator($elementTranslate);
         $this->assertFalse($this->element->isValid(123));
@@ -2104,18 +2100,18 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $formTranslations = array('alphaInvalid' => 'Form message');
         $formTranslate = new Zend_Translate('array', $formTranslations);
         Zend_Form::setDefaultTranslator($formTranslate);
-        
+
         $validatorTranslations = array('alphaInvalid' => 'Validator message');
         $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
         Zend_Validate_Abstract::setDefaultTranslator($validatorTranslate);
-        
+
         // the default validate translator should beat the registry one
         $this->element->addValidator('Alpha');
         $this->assertFalse($this->element->isValid(123));
         $messages = $this->element->getMessages();
         $this->assertEquals('Form message', $messages['alphaInvalid']);
     }
-    
+
     /**
      * @group ZF-9275
      */
@@ -2123,10 +2119,10 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     {
         $elementTranslations = array('alphaInvalid' => 'Element message');
         $elementTranslate = new Zend_Translate('array', $elementTranslations);
-        
+
         $validatorTranslations = array('alphaInvalid' => 'Direct validator message');
         $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
-        
+
         $validator = new Zend_Validate_Alpha();
         $validator->setTranslator($validatorTranslate);
         $this->element->addValidator($validator);
@@ -2161,6 +2157,38 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $t2 = $this->element->getDecorators();
         $this->assertEquals($t1, $t2);
     }
+
+    /**
+     * Check array notation for validators
+     */
+    public function testValidatorsGivenArrayKeysOnValidation()
+    {
+        $username = new Zend_Form_Element('username');
+        $username->addValidator('stringLength', true, array('min' => 5, 'max' => 20, 'ignore' => 'something'));
+        $form = new Zend_Form(array('elements' => array($username)));
+        $this->assertTrue($form->isValid(array('username' => 'abcde')));
+    }
+
+    /**
+     * @group ZF-6822
+     */
+    public function testValidatorByUsingStringNotation()
+    {
+        $this->_checkZf2794();
+
+        $username = new Zend_Form_Element('username');
+        $username->addValidator('stringLength', true, array(5, 20))
+                 ->addValidator('regex', true, '/^[a-zA-Z0-9_]*$/')
+                 ->addFilter('StringToLower')
+                 ->setRequired(true);
+        $form = new Zend_Form(array('elements' => array($username)));
+        $form->isValid(array('username' => '#'));
+
+        $validator = $username->getValidator('stringLength');
+        $this->assertTrue($validator->zfBreakChainOnFailure);
+        $validator = $username->getValidator('regex');
+        $this->assertTrue($validator->zfBreakChainOnFailure);
+    }
 }
 
 class Zend_Form_ElementTest_Decorator extends Zend_Form_Decorator_Abstract
@@ -2190,39 +2218,6 @@ class Zend_Form_ElementTest_ArrayFilter implements Zend_Filter_Interface
         }
         return (strstr($value, 'ba'));
     }
-
-    /**
-     * Check array notation for validators
-     */
-    public function testValidatorsGivenArrayKeysOnValidation()
-    {
-        $username = new Zend_Form_Element('username');
-        $username->addValidator('stringLength', true, array('min' => 5, 'max' => 20, 'ignore' => 'something'));
-        $form = new Zend_Form(array('elements' => array($username)));
-        $this->assertTrue($form->isValid(array('username' => 'abcde')));
-    }
-
-    /**
-     * @see ZF-6822
-     */
-    public function testValidatorByUsingStringNotation()
-    {
-        $this->_checkZf2794();
-
-        $username = new Zend_Form_Element('username');
-        $username->addValidator('stringLength', true, array(5, 20))
-                 ->addValidator('regex', true, '/^[a-zA-Z0-9_]*$/')
-                 ->addFilter('StringToLower')
-                 ->setRequired(true);
-        $form = new Zend_Form(array('elements' => array($username)));
-        $form->isValid(array('username' => '#'));
-
-        $validator = $username->getValidator('stringLength');
-        $this->assertTrue($validator->zfBreakChainOnFailure);
-        $validator = $username->getValidator('regex');
-        $this->assertTrue($validator->zfBreakChainOnFailure);
-    }
-    
 }
 
 if (PHPUnit_MAIN_METHOD == 'Zend_Form_ElementTest::main') {
