@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: SubFormTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: SubFormTest.php 24156 2011-06-27 14:57:44Z ezimuel $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
@@ -139,6 +139,24 @@ class Zend_Form_SubFormTest extends PHPUnit_Framework_TestCase
     {
         $this->assertSame($this->form, $this->form->loadDefaultDecorators());
     }
+    /**
+     * @see ZF-11504
+     */
+    public function testSubFormWithNumericName()
+    {
+        $subForm = new Zend_Form_SubForm(array(
+            'elements' => array(
+                'foo' => 'text',
+                'bar' => 'text',
+            ),
+        ));
+        $form = new Zend_Form();
+        $form->addSubForm($subForm, 0);
+        $form->addSubForm($subForm, 234);
+        $form2 = clone $form;
+        $this->assertEquals($form2->getSubForm(234)->getName(),234);
+        $this->assertEquals($form2->getSubForm(0)->getName(),0);
+    }
 }
 
 class Zend_Form_SubFormTest_SubForm extends Zend_Form_SubForm
