@@ -15,16 +15,11 @@
  * @category     Zend
  * @package      Zend_Gdata_YouTube
  * @subpackage   UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license      http://framework.zend.com/license/new-bsd     New BSD License
- * @version      $Id: VideoEntryTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version      $Id: VideoEntryTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 require_once 'Zend/Gdata/YouTube/VideoEntry.php';
 require_once 'Zend/Gdata/YouTube/Extension/State.php';
 require_once 'Zend/Gdata/YouTube.php';
@@ -33,7 +28,7 @@ require_once 'Zend/Gdata/YouTube.php';
  * @category   Zend
  * @package    Zend_Gdata_YouTube
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Gdata
  * @group      Zend_Gdata_YouTube
