@@ -15,17 +15,11 @@
  * @category   Zend
  * @package    Zend_Http_CookieJar
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: CookieJarTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: CookieJarTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(dirname(dirname(__FILE__))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
-require_once 'PHPUnit/Framework/TestCase.php';
 require_once 'Zend/Http/CookieJar.php';
 
 /**
@@ -34,7 +28,7 @@ require_once 'Zend/Http/CookieJar.php';
  * @category   Zend
  * @package    Zend_Http_CookieJar
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Http
  * @group      Zend_Http_CookieJar
