@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_InfoCard
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ProcessTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ProcessTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_InfoCard_ProcessTest::main() if this source file is executed directly.
@@ -25,14 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_InfoCard_ProcessTest::main");
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
-
 require_once 'Zend/InfoCard.php';
 require_once 'Zend/InfoCard/Adapter/Default.php';
 
@@ -40,7 +32,7 @@ require_once 'Zend/InfoCard/Adapter/Default.php';
  * @category   Zend
  * @package    Zend_InfoCard
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_InfoCard
  */
@@ -56,7 +48,6 @@ class Zend_InfoCard_ProcessTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_InfoCard_ProcessTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
