@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Layout
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: LayoutTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: LayoutTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Layout_LayoutTest::main() if this source file is executed directly.
@@ -25,10 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Layout_LayoutTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
-
 require_once 'Zend/Layout.php';
 require_once 'Zend/Layout/Controller/Plugin/Layout.php';
 require_once 'Zend/Layout/Controller/Action/Helper/Layout.php';
@@ -44,7 +40,7 @@ require_once 'Zend/View.php';
  * @category   Zend
  * @package    Zend_Layout
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Layout
  */
@@ -57,7 +53,6 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Layout_LayoutTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
