@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ConverterTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: ConverterTest.php 24354 2011-08-05 07:36:38Z sgehrig $
  */
 
 /**
@@ -181,8 +181,6 @@ class Zend_Ldap_ConverterTest extends PHPUnit_Framework_TestCase
 
     public function fromLdapDateTimeProvider ()
     {
-        $tz = new DateTimeZone('UTC');
-        $tz = null;
         return array (
                 array(new DateTime('2010-12-24 08:00:23+0300'),'20101224080023+0300', false),
                 array(new DateTime('2010-12-24 08:00:23+0300'),'20101224080023+03\'00\'', false),
@@ -219,5 +217,24 @@ class Zend_Ldap_ConverterTest extends PHPUnit_Framework_TestCase
                 array('20101231235959+1160'),
             );
     }
+
+	/**
+     * @dataProvider fromLdapProvider
+     */
+    public function testFromLdap($expect, $value, $type, $dateTimeAsUtc){
+        $this->assertSame($expect, Zend_Ldap_Converter::fromLdap($value, $type, $dateTimeAsUtc));
+    }
+
+    public function fromLdapProvider(){
+        return array(
+           array('1', '1', 0, true),
+           array('0', '0', 0, true),
+           array(true, 'TRUE', 0, true),
+           array(false, 'FALSE', 0, true),
+           array('123456789', '123456789', 0, true),
+           // ZF-11639
+           array('+123456789', '+123456789', 0, true),
+        );
+    }
 }
 
