@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: OfflineTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: OfflineTest.php 24352 2011-08-04 20:53:04Z sgehrig $
  */
 
 /**
@@ -595,4 +595,72 @@ class Zend_Ldap_Node_OfflineTest extends Zend_Ldap_TestCase
         $node->removeFromAttribute('test', array('value1', 'value3'));
         $this->assertEquals(array('value2'), $node->test);
     }
+
+    /**
+     * ZF-11611
+     */
+    public function testRdnAttributesHandleMultiValuedAttribute()
+    {
+        $data = array(
+        	'dn' => 'cn=funkygroup,ou=Groupes,dc=domain,dc=local',
+        	'objectClass' => array(
+        		'groupOfNames',
+        		'top',
+        	),
+        	'cn' => array(
+        		'The Funkygroup',
+        		'funkygroup',
+        	),
+        	'member' => 'uid=john-doe,ou=Users,dc=domain,dc=local',
+        );
+
+        $node = Zend_Ldap_Node::fromArray($data, true);
+        $this->assertEmpty($node->getChangedData());
+    }
+
+	/**
+     * ZF-11611
+     */
+    public function testRdnAttributesHandleMultiValuedAttribute2()
+    {
+        $data = array(
+        	'dn' => 'cn=funkygroup,ou=Groupes,dc=domain,dc=local',
+        	'objectClass' => array(
+        		'groupOfNames',
+        		'top',
+        	),
+        	'member' => 'uid=john-doe,ou=Users,dc=domain,dc=local',
+        );
+
+        $node = Zend_Ldap_Node::fromArray($data, true);
+        $cn = $node->getAttribute('cn');
+        $this->assertEquals(array(
+            0 => 'funkygroup'
+        ), $cn);
+    }
+
+	/**
+     * ZF-11611
+     */
+    public function testRdnAttributesHandleMultiValuedAttribute3()
+    {
+        $data = array(
+        	'dn' => 'cn=funkygroup,ou=Groupes,dc=domain,dc=local',
+        	'objectClass' => array(
+        		'groupOfNames',
+        		'top',
+        	),
+        	'cn' => array(
+        	    0 => 'The Funkygroup'
+        	),
+        	'member' => 'uid=john-doe,ou=Users,dc=domain,dc=local',
+        );
+
+        $node = Zend_Ldap_Node::fromArray($data, true);
+        $cn = $node->getAttribute('cn');
+        $this->assertEquals(array(
+           0 => 'The Funkygroup',
+           1 => 'funkygroup',
+        ), $cn);
+    }
 }
