@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Locale
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
@@ -24,8 +24,6 @@ if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_LocaleTest::main');
 }
 
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 // define('TESTS_ZEND_LOCALE_BCMATH_ENABLED', false); // uncomment to disable use of bcmath extension by Zend_Date
 
 /**
@@ -38,7 +36,7 @@ require_once 'Zend/Cache.php';
  * @category   Zend
  * @package    Zend_Locale
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Locale
  */
@@ -851,6 +849,17 @@ class Zend_LocaleTest extends PHPUnit_Framework_TestCase
         $value = new Zend_Locale('TR');
         $this->assertEquals('tr_TR', $value->toString());
     }
+    /**
+     * @group ZF-11072
+     */
+    public function testTranslationReturnsZeroAsNumber()
+    {
+        $this->assertFalse(Zend_Locale::getTranslation('USD', 'CurrencyFraction'));
+        $this->assertEquals('0', Zend_Locale::getTranslation('JPY', 'CurrencyFraction'));
+		$this->assertEquals('2', Zend_Locale::getTranslation('CHF', 'CurrencyFraction'));
+		$this->assertEquals('3', Zend_Locale::getTranslation('BHD', 'CurrencyFraction'));
+		$this->assertEquals('2', Zend_Locale::getTranslation('DEFAULT', 'CurrencyFraction'));
+    }
 
     /**
      * Ignores a raised PHP error when in effect, but throws a flag to indicate an error occurred
