@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MailTest.php 22632 2010-07-18 18:30:08Z ramon $
+ * @version    $Id: MailTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Log_Writer_MailTest::main() if this source file is executed directly.
@@ -25,11 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Log_Writer_MailTest::main");
 }
 
-/**
- * Test helper
- */
-require_once realpath(dirname(__FILE__) . '/../../..') . '/TestHelper.php';
-
 /** Zend_Layout */
 require_once 'Zend/Layout.php';
 
@@ -48,16 +43,27 @@ require_once 'Zend/Mail/Transport/Exception.php';
 /** Zend_View_Exception */
 require_once 'Zend/View/Exception.php';
 
+/** For some reason these classed have to be manually loaded, because PHPUnit fails to autoload them */
+require_once 'PHPUnit/Framework/MockObject/Stub/Exception.php';
+
+
 /**
  * @category   Zend
  * @package    Zend_Log
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Log
  */
 class Zend_Log_Writer_MailTest extends PHPUnit_Framework_TestCase
 {
+    /**
+     * Mock Transport for Zend_Mail
+     *
+     * @var Zend_Mail_Transport_Abstract
+     */
+    protected $_transport;
+
     /**
      * Runs the test methods of this class.
      *
@@ -65,11 +71,24 @@ class Zend_Log_Writer_MailTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
-        $suite = new PHPUnit_Framework_TestSuite("Zend_Log_Writer_MailTest");
+        $suite = new PHPUnit_Framework_TestSuite(__CLASS__);
         $result = PHPUnit_TextUI_TestRunner::run($suite);
     }
 
+    protected function setUp()
+    {
+        $this->_transport = $this->getMockForAbstractClass(
+            'Zend_Mail_Transport_Abstract',
+            array()
+        );
+        Zend_Mail::setDefaultTransport($this->_transport);
+    }
+
+    protected function tearDown()
+    {
+        Zend_Mail::clearDefaultTransport();
+    }
+
     /**
      * Tests normal logging, but with multiple messages for a level.
      *
@@ -273,6 +292,175 @@ class Zend_Log_Writer_MailTest extends PHPUnit_Framework_TestCase
         unset($log);
     }
 
+    /**
+     * @group ZF-8953
+     */
+    public function testFluentInterface()
+    {
+        require_once 'Zend/Log/Formatter/Simple.php';
+        list(, $writer) = $this->_getSimpleLogger(true);
+        $instance = $writer->setLayoutFormatter(new Zend_Log_Formatter_Simple())
+                           ->setSubjectPrependText('subject');
+
+        $this->assertTrue($instance instanceof Zend_Log_Writer_Mail);
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactory()
+    {
+    	$config = array(
+    		'from' => array(
+    		    'email' => 'log@test.framework.zend.com'
+    	    ),
+    		'to' => 'admin@domain.com',
+    		'subject' => '[error] exceptions on my application'
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$this->assertType('Zend_Log_Writer_Mail', $writer);
+
+    	$writer->write($this->_getEvent());
+    	$writer->shutdown();
+
+    	$this->assertEquals('admin@domain.com', $this->_transport->recipients);
+    	$this->assertContains('an info message', $this->_transport->body);
+    	$this->assertContains('From: log@test.framework.zend.com', $this->_transport->header);
+    	$this->assertContains('To: admin@domain.com', $this->_transport->header);
+    	$this->assertContains('Subject: [error] exceptions on my application', $this->_transport->header);
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactoryShouldSetSubjectPrependText()
+    {
+    	$config = array(
+    		'subjectPrependText' => '[error] exceptions on my application'
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$writer->write($this->_getEvent());
+    	$writer->shutdown();
+
+    	$this->assertContains('Subject: [error] exceptions on my application (INFO=1)', $this->_transport->header);
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactoryShouldAcceptCustomMailClass()
+    {
+        $this->getMock('Zend_Mail', array(), array(), 'Zend_Stub_Mail_Custom');
+        $config = array(
+            'class' => 'Zend_Stub_Mail_Custom'
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$this->assertType('Zend_Log_Writer_Mail', $writer);
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactoryShouldSetCharsetForMail()
+    {
+        $config = array(
+            'charset' => 'UTF-8'
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$writer->write($this->_getEvent());
+    	$writer->shutdown();
+
+    	$this->assertContains('Content-Type: text/plain; charset=UTF-8', $this->_transport->header);
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactoryShouldAllowToSetMultipleRecipientsInArray()
+    {
+    	$config = array(
+    		'to' => array(
+    		    'John Doe' => 'admin1@domain.com',
+    	        'admin2@domain.com'
+    	    ),
+    	    'cc' => array(
+    	        'bug@domain.com',
+    		    'project' => 'projectname@domain.com'
+    	    )
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$writer->write($this->_getEvent());
+    	$writer->shutdown();
+
+    	$this->assertContains('admin1@domain.com', $this->_transport->recipients);
+    	$this->assertContains('admin2@domain.com', $this->_transport->recipients);
+    	$this->assertContains('bug@domain.com', $this->_transport->recipients);
+    	$this->assertContains('projectname@domain.com', $this->_transport->recipients);
+    	$this->assertContains('To: John Doe <admin1@domain.com>', $this->_transport->header);
+    	$this->assertContains('admin2@domain.com', $this->_transport->header);
+    	$this->assertContains('Cc: bug@domain.com', $this->_transport->header);
+    	$this->assertContains('project <projectname@domain.com>', $this->_transport->header);
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactoryWithLayout()
+    {
+    	$config = array(
+    	    'layoutOptions' => array(
+    	        'layoutPath' => dirname(__FILE__) . '/_files'
+    	    )
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$writer->write($this->_getEvent());
+    	$writer->shutdown();
+
+        $this->assertFalse(empty($this->_transport->boundary));
+        $this->assertContains('Content-Type: multipart/', $this->_transport->header);
+        $this->assertContains('boundary=', $this->_transport->header);
+        $this->assertContains('Content-Type: text/plain', $this->_transport->body);
+        $this->assertContains('Content-Type: text/html', $this->_transport->body);
+        $this->assertContains($this->_transport->boundary, $this->_transport->body);
+        $this->assertEquals(2, substr_count($this->_transport->body, 'an info message'));
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactoryShouldSetLayoutFormatter()
+    {
+    	$config = array(
+    	    'layoutOptions' => array(
+    	        'layoutPath' => '/path/to/layout/scripts'
+    	    ),
+    	    'layoutFormatter' => 'Zend_Log_Formatter_Simple'
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$this->assertType('Zend_Log_Formatter_Simple', $writer->getLayoutFormatter());
+    }
+
+    /**
+     * @group ZF-9990
+     */
+    public function testFactoryWithCustomLayoutClass()
+    {
+        $this->getMock('Zend_Layout', null, array(), 'Zend_Stub_Layout_Custom');
+    	$config = array(
+    	    'layout' => 'Zend_Stub_Layout_Custom'
+    	);
+
+    	$writer = Zend_Log_Writer_Mail::factory($config);
+    	$this->assertType('Zend_Log_Writer_Mail', $writer);
+    }
+
     /**
      * Returns an array of the Zend_Mail mock object, Zend_Log_Writer_Mail
      * object, and Zend_Log objects.
@@ -311,9 +499,24 @@ class Zend_Log_Writer_MailTest extends PHPUnit_Framework_TestCase
 
         return array($mail, $writer, $log, $layout);
     }
+
+    /**
+     * Returns a sample of an event
+     *
+     * @return array
+     */
+    protected function _getEvent()
+    {
+        return array(
+    	    'timestamp'    => date('c'),
+            'message'      => 'an info message',
+            'priority'     => 6,
+            'priorityName' => 'INFO'
+    	);
+    }
 }
 
 // Call Zend_Log_Writer_MailTest::main() if this source file is executed directly.
 if (PHPUnit_MAIN_METHOD == "Zend_Log_Writer_MailTest::main") {
     Zend_Log_Writer_MailTest::main();
-}
+}
\ No newline at end of file
