@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
 
-/**
- * Test helper
- */
-require_once dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
 /**
  * Zend_Mail
  */
@@ -61,7 +56,7 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Mail_Transport_Mock extends Zend_Mail_Transport_Abstract
@@ -93,7 +88,7 @@ class Zend_Mail_Transport_Mock extends Zend_Mail_Transport_Abstract
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Mail_Transport_Sendmail_Mock extends Zend_Mail_Transport_Sendmail
@@ -119,7 +114,7 @@ class Zend_Mail_Transport_Sendmail_Mock extends Zend_Mail_Transport_Sendmail
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Mail
  */
@@ -213,6 +208,7 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
         $mail->setSubject('Test recipients Header format.');
         $mail->addTo('address_to1@example.com', 'name_to@example.com');
         $mail->addTo('address_to2@example.com', 'noinclude comma nor at mark');
+        $mail->addTo('address_to3@example.com', 'include brackets []');
         $mail->addCc('address_cc@example.com', 'include, name_cc');
 
         $mock = new Zend_Mail_Transport_Mock();
@@ -223,6 +219,7 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
         $this->assertContains('Test recipients Header format.', $mock->body);
         $this->assertContains('To: "name_to@example.com" <address_to1@example.com>', $mock->header);
         $this->assertContains('noinclude comma nor at mark <address_to2@example.com>', $mock->header);
+        $this->assertContains('"include brackets []" <address_to3@example.com>', $mock->header);
         $this->assertContains('Cc: "include, name_cc" <address_cc@example.com>', $mock->header);
     }
 
@@ -950,7 +947,7 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
         $this->assertEquals($headers['From'][0], 'John Doe <john@example.com>');
         $this->assertEquals($headers['Reply-To'][0], 'Foo Bar <foo@example.com>');
     }
-    
+
     /**
      * @group ZF-9011
      */
@@ -963,14 +960,14 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
 
         $params = array('envelope'=> '-tjohn@example.com', 'foo' => '-fbar');
         $expected = '-tjohn@example.com -fbar';
-        
+
         $transportMock = new Zend_Mail_Transport_Sendmail_Mock($params);
         $this->assertEquals($expected, $transportMock->parameters);
 
         $transportMock = new Zend_Mail_Transport_Sendmail_Mock(new Zend_Config($params));
         $this->assertEquals($expected, $transportMock->parameters);
     }
-    
+
     /**
      * @group ZF-9011
      *
@@ -992,6 +989,22 @@ class Zend_Mail_MailTest extends PHPUnit_Framework_TestCase
         }
     }
 
+    /**
+     * @group ZF-10367
+     */
+    public function testClearHeader()
+    {
+        $mail = new Zend_Mail();
+
+        $mail->addHeader('foo', 'bar');
+        $headers = $mail->getHeaders();
+        $this->assertTrue(isset($headers['foo']));
+
+        $mail->clearHeader('foo');
+        $headers = $mail->getHeaders();
+        $this->assertFalse(isset($headers['foo']));
+    }
+
     public static function dataSubjects()
     {
         return array(
