@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_OpenId
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: SregTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: SregTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 /**
@@ -26,16 +26,11 @@
 require_once 'Zend/OpenId/Extension/Sreg.php';
 
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework.php';
-
 /**
  * @category   Zend
  * @package    Zend_OpenId
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_OpenId
  */
