@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ProviderTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: ProviderTest.php 24333 2011-07-31 16:27:10Z ramon $
  */
 
 /**
@@ -30,6 +30,11 @@ require_once 'Zend/OpenId/Provider.php';
  */
 require_once 'Zend/OpenId/ResponseHelper.php';
 
+/**
+ * @see Zend_OpenId_Provider_User_Session
+ */
+require_once 'Zend/OpenId/Provider/User/Session.php';
+
 /**
  * @category   Zend
  * @package    Zend_OpenId
