@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_ProgressBar
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ProgressBarTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ProgressBarTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Console_ProgressBarTest::main() if this source file is executed directly.
@@ -25,11 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_ProgressBar_ProgressBarTest::main");
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * Zend_ProgressBar
  */
@@ -44,7 +39,7 @@ require_once 'Zend/ProgressBar/Adapter.php';
  * @category   Zend
  * @package    Zend_Console
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_ProgressBar
  */
