@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Queue
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AdapterTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: AdapterTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 /*
@@ -28,12 +28,6 @@
  * an exception.
  */
 
-/** PHPUnit Test Case */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-/** TestHelp.php */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /** Zend_Queue */
 require_once 'Zend/Queue.php';
 
@@ -55,7 +49,7 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Queue
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Queue
  */
@@ -148,10 +142,20 @@ abstract class Zend_Queue_Adapter_AdapterTest extends PHPUnit_Framework_TestCase
         try {
             $queue = new Zend_Queue($this->getAdapterName(), $config);
         } catch (Zend_Queue_Exception $e) {
-            $this->markTestSkipped();
+            $this->markTestSkipped($e->getMessage());
             restore_error_handler();
             return false;
         }
+
+        // a PHP level error occurred, mark test as failed with error as reason
+        // (misconfigured test? undefined constant?)
+        if ($this->error) {
+            $err = error_get_last();
+            $this->markTestFailed($err['message']);
+            restore_error_handler();
+            return false;
+        }
+
         restore_error_handler();
 
         return $queue;
