@@ -15,14 +15,11 @@
  * @category   Zend
  * @package    Zend_Queue
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FactoryTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: FactoryTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/** PHPUnit Test Case */
-require_once 'PHPUnit/Framework/TestCase.php';
-
 /** Zend_Queue */
 require_once 'Zend/Queue.php';
 
@@ -35,13 +32,11 @@ require_once 'Zend/Queue/Adapter/Db.php';
 require_once 'Zend/Queue/Adapter/Memcacheq.php';
 require_once 'Zend/Queue/Adapter/ActivemqTest.php';
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @category   Zend
  * @package    Zend_Queue
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Queue
  */
