@@ -17,10 +17,11 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ParamTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: ParamTest.php 24405 2011-08-26 17:33:02Z ralph $
  */
 
 require_once 'Zend/Reflection/File.php';
+require_once 'Zend/Reflection/Docblock/Tag/Param.php';
 
 /**
  * @category   Zend
@@ -87,5 +88,17 @@ class Zend_Reflection_Docblock_Tag_ParamTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('$var', $paramTag->getVariableName());
         $this->assertEquals('desc', $paramTag->getDescription());
     }
+
+    /**
+     * @group ZF-8373
+     */
+    public function testArrayNotationInParam()
+    {
+        $targetLine = '@param string[] $foo An array of strings';
+        $param = new Zend_Reflection_Docblock_Tag_Param($targetLine);
+        $this->assertEquals('string[]', $param->getType());
+        $this->assertEquals('$foo', $param->getVariableName());
+        $this->assertEquals('An array of strings', $param->getDescription());
+    }
 }
 
