@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ReturnTest.php 23775 2011-03-01 17:25:24Z ralph $
+ * @version    $Id: ReturnTest.php 24405 2011-08-26 17:33:02Z ralph $
  */
 
 require_once 'Zend/Reflection/File.php';
@@ -76,4 +76,16 @@ class Zend_Reflection_Docblock_Tag_ReturnTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals('Zend\Reflection\Docblock', $paramTag->getType());
     }
+
+    /**
+     * @group ZF-8373
+     */
+    public function testArrayNotationInParam()
+    {
+        $targetLine = '@param string[] $foo An array of strings';
+        $param = new Zend_Reflection_Docblock_Tag_Param($targetLine);
+        $this->assertEquals('string[]', $param->getType());
+        $this->assertEquals('$foo', $param->getVariableName());
+        $this->assertEquals('An array of strings', $param->getDescription());
+    }
 }
