@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ServerTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ServerTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_Rest_ServerTest::main() if this source file is executed directly.
@@ -25,8 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Rest_ServerTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * Zend_Rest_Server
  */
@@ -38,7 +36,7 @@ require_once 'Zend/Rest/Server.php';
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Rest
  * @group      Zend_Rest_Server
@@ -52,7 +50,6 @@ class Zend_Rest_ServerTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Rest_ServerTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
