@@ -15,20 +15,15 @@
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: LuceneTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: LuceneTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Search_Lucene_LuceneTest::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * Zend_Search_Lucene
  */
@@ -38,7 +33,7 @@ require_once 'Zend/Search/Lucene.php';
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Search_Lucene
  */
@@ -69,8 +64,8 @@ class Zend_Search_Lucene_LuceneTest extends PHPUnit_Framework_TestCase
     public function testCreate()
     {
         $index = Zend_Search_Lucene::create(dirname(__FILE__) . '/_index/_files');
-
         $this->assertTrue($index instanceof Zend_Search_Lucene_Interface);
+        unset($index);
 
         $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
     }
@@ -323,6 +318,7 @@ class Zend_Search_Lucene_LuceneTest extends PHPUnit_Framework_TestCase
 
         $index1 = Zend_Search_Lucene::open(dirname(__FILE__) . '/_index/_files');
         $this->assertTrue($index1 instanceof Zend_Search_Lucene_Interface);
+        unset($index1);
 
         $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
     }
@@ -381,6 +377,7 @@ class Zend_Search_Lucene_LuceneTest extends PHPUnit_Framework_TestCase
 
         $hits = $index2->find('submitting');
         $this->assertEquals(count($hits), 3);
+        unset($index2);
 
         $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
     }
@@ -466,6 +463,7 @@ class Zend_Search_Lucene_LuceneTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($index->currentTerm() === null);
 
         $index->closeTermsStream();
+        unset($index);
 
         $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
     }
@@ -490,6 +488,7 @@ class Zend_Search_Lucene_LuceneTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($index->currentTerm() === null);
 
         $index->closeTermsStream();
+        unset($index);
 
         $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
     }
@@ -514,6 +513,59 @@ class Zend_Search_Lucene_LuceneTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($index->currentTerm() == new Zend_Search_Lucene_Index_Term('word', 'contents'));
 
         $index->closeTermsStream();
+        unset($index);
+
+        $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
+    }
+
+    /**
+     * @group ZF-7518
+     */
+    public function testTermsStreamInterfaceSkipToMatchedTerm()
+    {
+        $index = Zend_Search_Lucene::create(dirname(__FILE__) . '/_index/_files');
+
+        $doc = new Zend_Search_Lucene_Document();
+        $doc->addField(Zend_Search_Lucene_Field::Keyword('test', 'f'));
+        $index->addDocument($doc);
+
+        unset($index);
+
+
+        $index = Zend_Search_Lucene::open(dirname(__FILE__) . '/_index/_files');
+
+        $hits = $index->find('test:[a TO t]');
+        $this->assertEquals(1, count($hits));
+        $this->assertEquals(0, reset($hits)->id);
+
+        $hits = $index->find('test:f');
+        $this->assertEquals(1, count($hits));
+        $this->assertEquals(0, reset($hits)->id);
+
+        $hits = $index->find('test:g');
+        $this->assertEquals(0, count($hits));
+
+        unset($index);
+
+        $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
+    }
+
+    /**
+     * @group ZF-9680
+     */
+    public function testIsDeletedWithoutExplicitCommit()
+    {
+        //$this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
+
+        $index = Zend_Search_Lucene::create(dirname(__FILE__) . '/_index/_files');
+
+        $document = new Zend_Search_Lucene_Document;
+        $document->addField(Zend_Search_Lucene_Field::Keyword('_id', 'myId'));
+        $document->addField(Zend_Search_Lucene_Field::Keyword('bla', 'blubb'));
+        $index->addDocument($document);
+
+        $this->assertFalse($index->isDeleted(0));
+        unset($index);
 
         $this->_clearDirectory(dirname(__FILE__) . '/_index/_files');
     }
