@@ -15,13 +15,11 @@
  * @category   Zend
  * @package    Zend_Service_Amazon
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: AllTests.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-require_once dirname(dirname(dirname(dirname(__FILE__)))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Service_Amazon_AllTests::main');
 }
@@ -30,13 +28,15 @@ require_once 'Zend/Service/Amazon/OfflineTest.php';
 require_once 'Zend/Service/Amazon/OnlineTest.php';
 require_once 'Zend/Service/Amazon/Ec2/AllTests.php';
 require_once 'Zend/Service/Amazon/S3/AllTests.php';
+require_once 'Zend/Service/Amazon/SimpleDb/AllTests.php';
 require_once 'Zend/Service/Amazon/Sqs/AllTests.php';
+require_once 'Zend/Service/Amazon/Authentication/AllTests.php';
 
 /**
  * @category   Zend
  * @package    Zend_Service_Amazon
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Service
  * @group      Zend_Service_Amazon
@@ -71,8 +71,10 @@ class Zend_Service_Amazon_AllTests
             $suite->addTestSuite('Zend_Service_Amazon_OnlineTest_Skip');
         }
 
+        $suite->addTest(Zend_Service_Amazon_Authentication_AllTests::suite());
         $suite->addTest(Zend_Service_Amazon_Ec2_AllTests::suite());
         $suite->addTest(Zend_Service_Amazon_S3_AllTests::suite());
+        $suite->addTest(Zend_Service_Amazon_SimpleDb_AllTests::suite());
         $suite->addTest(Zend_Service_Amazon_Sqs_AllTests::suite());
 
         return $suite;
