@@ -15,13 +15,11 @@
  * @category   Zend
  * @package    Zend_Service_Amazon
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id: AbstractTest.php 17667 2009-08-18 21:40:09Z mikaelkael $
  */
 
-require_once dirname(dirname(dirname(dirname(dirname(__FILE__))))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
 require_once 'Zend/Service/Amazon/Ec2/Abstract.php';
 
 /**
@@ -30,7 +28,7 @@ require_once 'Zend/Service/Amazon/Ec2/Abstract.php';
  * @category   Zend
  * @package    Zend_Service_Amazon
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Service
  * @group      Zend_Service_Amazon
@@ -57,49 +55,49 @@ class Zend_Service_Amazon_Ec2_AbstractTest extends PHPUnit_Framework_TestCase
     public function testNoKeysThrowException()
     {
         try {
-            $class = new TestAmamzonAbstract();
+            $class = new TestAmamzonEc2Abstract();
             $this->fail('Exception should be thrown when no keys are passed in.');
         } catch(Zend_Service_Amazon_Exception $zsae) {}
     }
 
     public function testSetRegion()
     {
-        TestAmamzonAbstract::setRegion('eu-west-1');
+        TestAmamzonEc2Abstract::setRegion('eu-west-1');
 
-        $class = new TestAmamzonAbstract('TestAccessKey', 'TestSecretKey');
+        $class = new TestAmamzonEc2Abstract('TestAccessKey', 'TestSecretKey');
         $this->assertEquals('eu-west-1', $class->returnRegion());
     }
 
     public function testSetInvalidRegionThrowsException()
     {
         try {
-            TestAmamzonAbstract::setRegion('eu-west-1a');
+            TestAmamzonEc2Abstract::setRegion('eu-west-1a');
             $this->fail('Invalid Region Set with no Exception Thrown');
         } catch (Zend_Service_Amazon_Exception $zsae) {
             // do nothing
         }
     }
-    
+
     public function testSignParamsWithSpaceEncodesWithPercentInsteadOfPlus()
     {
-        $class = new TestAmamzonAbstract('TestAccessKey', 'TestSecretKey');
+        $class = new TestAmamzonEc2Abstract('TestAccessKey', 'TestSecretKey');
         $ret = $class->testSign(array('Action' => 'Space Test'));
-        
+
         // this is the encode signuature with urlencode - It's Invalid!
         $invalidSignature = 'EeHAfo7cMcLyvH4SW4fEpjo51xJJ4ES1gdjRPxZTlto=';
-        
+
         $this->assertNotEquals($ret, $invalidSignature);
     }
 }
 
-class TestAmamzonAbstract extends Zend_Service_Amazon_Ec2_Abstract
+class TestAmamzonEc2Abstract extends Zend_Service_Amazon_Ec2_Abstract
 {
 
     public function returnRegion()
     {
         return $this->_region;
     }
-    
+
     public function testSign($params)
     {
         return $this->signParameters($params);
