@@ -15,20 +15,15 @@
  * @category   Zend
  * @package    Zend_Service_DeveloperGarden
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ConferenceCallTest.php 20166 2010-01-09 19:00:17Z bkarwin $
+ * @version    $Id: ConferenceCallTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Service_DeveloperGarden_ConferenceCallTest::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /**
  * @see Zend_Service_DeveloperGarden_ConferenceCall
  */
@@ -40,9 +35,9 @@ require_once 'Zend/Service/DeveloperGarden/ConferenceCall.php';
  * @category   Zend
  * @package    Zend_Service_DeveloperGarden
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ConferenceCallTest.php 20166 2010-01-09 19:00:17Z bkarwin $
+ * @version    $Id: ConferenceCallTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 class Zend_Service_DeveloperGarden_ConferenceCallTest extends PHPUnit_Framework_TestCase
 {
