@@ -16,15 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 require_once 'Zend/Service/WindowsAzure/Credentials/AllTests.php';
 require_once 'Zend/Service/WindowsAzure/Diagnostics/AllTests.php';
 require_once 'Zend/Service/WindowsAzure/RetryPolicyTest.php';
@@ -44,7 +39,7 @@ require_once 'Zend/Service/WindowsAzure/SessionHandlerTest.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_AllTests
@@ -56,7 +51,7 @@ class Zend_Service_WindowsAzure_AllTests
 
         $suite->addTest(Zend_Service_WindowsAzure_Credentials_AllTests::suite());
         $suite->addTest(Zend_Service_WindowsAzure_Diagnostics_AllTests::suite());
-        
+
         $suite->addTestSuite('Zend_Service_WindowsAzure_RetryPolicyTest');
         $suite->addTestSuite('Zend_Service_WindowsAzure_StorageTest');
         $suite->addTestSuite('Zend_Service_WindowsAzure_BlobStorageTest');
