@@ -16,15 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /** Zend_Service_WindowsAzure_Storage_Blob */
 require_once 'Zend/Service/WindowsAzure/Storage/Blob.php';
 
@@ -36,18 +31,18 @@ require_once 'Zend/Service/WindowsAzure/Credentials/SharedAccessSignature.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_BlobStorageSharedAccessTest extends PHPUnit_Framework_TestCase
 {
     static protected $path;
-    
+
     public function __construct()
     {
         self::$path = dirname(__FILE__).'/_files/';
     }
-    
+
     /**
      * Test setup
      */
@@ -57,7 +52,7 @@ class Zend_Service_WindowsAzure_BlobStorageSharedAccessTest extends PHPUnit_Fram
             $this->markTestSkipped('This test case requires TESTS_ZEND_SERVICE_WINDOWSAZURE_BLOB_RUNTESTS to be enabled in TestConfiguration.php');
         }
     }
-    
+
     /**
      * Test teardown
      */
@@ -66,7 +61,7 @@ class Zend_Service_WindowsAzure_BlobStorageSharedAccessTest extends PHPUnit_Fram
         if ($this->status == PHPUnit_Runner_BaseTestRunner::STATUS_SKIPPED) {
             return;
         }
-        
+
         $storageClient = $this->createAdministrativeStorageInstance();
         for ($i = 1; $i <= self::$uniqId; $i++)
         {
@@ -89,14 +84,14 @@ class Zend_Service_WindowsAzure_BlobStorageSharedAccessTest extends PHPUnit_Fram
                 new Zend_Service_WindowsAzure_Credentials_SharedAccessSignature(TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_ACCOUNT_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_KEY_DEV, true)
             );
         }
-        
+
         if (TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY) {
             $storageClient->setProxy(TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_PORT, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_CREDENTIALS);
         }
 
         return $storageClient;
     }
-    
+
     protected function createAdministrativeStorageInstance()
     {
         $storageClient = null;
@@ -105,43 +100,43 @@ class Zend_Service_WindowsAzure_BlobStorageSharedAccessTest extends PHPUnit_Fram
         } else {
             $storageClient = new Zend_Service_WindowsAzure_Storage_Blob(TESTS_ZEND_SERVICE_WINDOWSAZURE_BLOB_HOST_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_ACCOUNT_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_KEY_DEV, true, Zend_Service_WindowsAzure_RetryPolicy_RetryPolicyAbstract::retryN(10, 250));
         }
-        
+
         if (TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY) {
             $storageClient->setProxy(TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_PORT, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_CREDENTIALS);
         }
 
         return $storageClient;
     }
-    
+
     protected static $uniqId = 0;
-    
+
     protected function generateName()
     {
         self::$uniqId++;
         return TESTS_ZEND_SERVICE_WINDOWSAZURE_BLOBSA_CONTAINER_PREFIX . self::$uniqId;
     }
-    
+
     /**
      * Test shared access, only write
      */
     public function testSharedAccess_OnlyWrite()
     {
         $containerName = $this->generateName();
-        
+
         // Account owner performs this part
         $administrativeStorageClient = $this->createAdministrativeStorageInstance();
         $administrativeStorageClient->createContainer($containerName);
-        
+
         $sharedAccessUrl = $administrativeStorageClient->generateSharedAccessUrl(
             $containerName,
             '',
-        	'c', 
+        	'c',
         	'w',
         	$administrativeStorageClient->isoDate(time() - 500),
         	$administrativeStorageClient->isoDate(time() + 3000)
         );
 
-        
+
         // Reduced permissions user performs this part
         $storageClient = $this->createStorageInstance();
         $credentials = $storageClient->getCredentials();
@@ -153,9 +148,9 @@ class Zend_Service_WindowsAzure_BlobStorageSharedAccessTest extends PHPUnit_Fram
 
         $this->assertEquals($containerName, $result->Container);
         $this->assertEquals('images/WindowsAzure.gif', $result->Name);
-        
-        
-        
+
+
+
         // Now make sure reduced permissions user can not view the uploaded blob
         $exceptionThrown = false;
         try {
@@ -165,29 +160,29 @@ class Zend_Service_WindowsAzure_BlobStorageSharedAccessTest extends PHPUnit_Fram
         }
         $this->assertTrue($exceptionThrown);
     }
-    
+
     /**
      * Test different accounts
      */
     public function testDifferentAccounts()
     {
         $containerName = $this->generateName();
-        
+
         // Account owner performs this part
         $administrativeStorageClient = $this->createAdministrativeStorageInstance();
         $administrativeStorageClient->createContainer($containerName);
-        
+
         $sharedAccessUrl1 = $administrativeStorageClient->generateSharedAccessUrl(
             $containerName,
             '',
-        	'c', 
+        	'c',
         	'w',
         	$administrativeStorageClient->isoDate(time() - 500),
         	$administrativeStorageClient->isoDate(time() + 3000)
         );
         $sharedAccessUrl2 = str_replace($administrativeStorageClient->getAccountName(), 'bogusaccount', $sharedAccessUrl1);
 
-        
+
         // Reduced permissions user performs this part and should fail,
         // because different accounts have been used
         $storageClient = $this->createStorageInstance();
