@@ -16,15 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 /** Zend_Service_WindowsAzure_Credentials_SharedAccessSignature */
 require_once 'Zend/Service/WindowsAzure/Credentials/SharedAccessSignature.php';
 
@@ -33,12 +28,12 @@ require_once 'Zend/Service/WindowsAzure/Credentials/SharedAccessSignature.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_Credentials_SharedAccessSignatureTest extends PHPUnit_Framework_TestCase
 {
-    
+
     /**
      * Test signing a container
      */
@@ -55,7 +50,7 @@ class Zend_Service_WindowsAzure_Credentials_SharedAccessSignatureTest extends PH
         );
         $this->assertEquals('TEfqYYiY9Qrb7fH7nhiRCP9o5BzfO/VL8oYgfVpUl6s=', $result);
     }
-    
+
     /**
      * Test signing a blob
      */
@@ -71,7 +66,7 @@ class Zend_Service_WindowsAzure_Credentials_SharedAccessSignatureTest extends PH
         );
         $this->assertEquals('hk78uZGGWd8B2NYoBwKSPs5gen3xYqsd3DPO8BQhgTU=', $result);
     }
-    
+
     /**
      * Test container signed query string
      */
@@ -89,7 +84,7 @@ class Zend_Service_WindowsAzure_Credentials_SharedAccessSignatureTest extends PH
         );
         $this->assertEquals('st=2009-02-09&se=2009-02-10&sr=c&sp=r&si=YWJjZGVmZw%3D%3D&sig=iLe%2BC%2Be85l8%2BMneC9psdTCg7hJxKh314aRq3SnqPuyM%3D', $result);
     }
-    
+
     /**
      * Test blob signed query string
      */
@@ -106,7 +101,7 @@ class Zend_Service_WindowsAzure_Credentials_SharedAccessSignatureTest extends PH
         );
         $this->assertEquals('st=2009-02-09&se=2009-02-10&sr=b&sp=w&sig=MUrHltHOJkj4425gorWWKr%2FO6mHC3XeRQ2MD6jn8jI8%3D', $result);
     }
-    
+
     /**
      * Test sign request URL
      */
@@ -114,14 +109,14 @@ class Zend_Service_WindowsAzure_Credentials_SharedAccessSignatureTest extends PH
     {
         $credentials = new Zend_Service_WindowsAzure_Credentials_SharedAccessSignature('myaccount', '', false);
         $queryString = $credentials->createSignedQueryString('pictures/blob.txt', '', 'b', 'r', '2009-02-09', '2009-02-10');
-        
+
         $credentials->setPermissionSet(array(
             'http://blob.core.windows.net/myaccount/pictures/blob.txt?' . $queryString
         ));
 
         $requestUrl = 'http://blob.core.windows.net/myaccount/pictures/blob.txt?comp=metadata';
         $result = $credentials->signRequestUrl($requestUrl, Zend_Service_WindowsAzure_Storage::RESOURCE_BLOB);
-        
+
         $this->assertEquals('http://blob.core.windows.net/myaccount/pictures/blob.txt?comp=metadata&' . $queryString, $result);
     }
 }
