@@ -16,15 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../../TestHelper.php';
-
 require_once 'Zend/Service/WindowsAzure/Diagnostics/ManagerTest.php';
 
 /**
@@ -32,7 +27,7 @@ require_once 'Zend/Service/WindowsAzure/Diagnostics/ManagerTest.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_Diagnostics_AllTests
@@ -43,7 +38,7 @@ class Zend_Service_WindowsAzure_Diagnostics_AllTests
         $suite = new PHPUnit_Framework_TestSuite();
 
         $suite->addTestSuite('Zend_Service_WindowsAzure_Diagnostics_ManagerTest');
-        
+
         return $suite;
     }
 }
