@@ -16,15 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /** Zend_Service_WindowsAzure_SessionHandler */
 require_once 'Zend/Service/WindowsAzure/SessionHandler.php';
 
@@ -36,14 +31,14 @@ require_once 'Zend/Service/WindowsAzure/Storage/Table.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_TestCase
 {
-    
+
     protected static $uniqId = 0;
-    
+
     public function __construct()
     {
     }
@@ -57,7 +52,7 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
             $this->markTestSkipped('This test case requires TESTS_ZEND_SERVICE_WINDOWSAZURE_SESSIONHANDLER_RUNTESTS to be enabled in TestConfiguration.php');
         }
     }
-    
+
     /**
      * Test teardown
      */
@@ -72,7 +67,7 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
             try { $storageClient->deleteTable(TESTS_ZEND_SERVICE_WINDOWSAZURE_SESSIONHANDLER_TABLENAME_PREFIX . $i); } catch (Exception $e) { }
         }
     }
-    
+
     protected function createStorageInstance()
     {
         $storageClient = null;
@@ -81,14 +76,14 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         } else {
             $storageClient = new Zend_Service_WindowsAzure_Storage_Table(TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_HOST_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_ACCOUNT_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_KEY_DEV, true, Zend_Service_WindowsAzure_RetryPolicy_RetryPolicyAbstract::retryN(10, 250));
         }
-        
+
         if (TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY) {
             $storageClient->setProxy(TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_PORT, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_CREDENTIALS);
         }
 
         return $storageClient;
     }
-    
+
     protected function createSessionHandler($storageInstance, $tableName)
     {
         $sessionHandler = new Zend_Service_WindowsAzure_SessionHandler(
@@ -97,13 +92,13 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         );
         return $sessionHandler;
     }
-   
+
     protected function generateName()
     {
         self::$uniqId++;
         return TESTS_ZEND_SERVICE_WINDOWSAZURE_SESSIONHANDLER_TABLENAME_PREFIX . self::$uniqId;
     }
-    
+
     /**
      * Test register
      */
@@ -113,10 +108,10 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         $tableName = $this->generateName();
         $sessionHandler = $this->createSessionHandler($storageClient, $tableName);
         $result = $sessionHandler->register();
-        
+
         $this->assertTrue($result);
     }
-    
+
     /**
      * Test open
      */
@@ -128,11 +123,11 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         $result = $sessionHandler->open();
 
         $this->assertTrue($result);
-        
+
         $verifyResult = $storageClient->listTables();
         $this->assertEquals($tableName, $verifyResult[0]->Name);
     }
-    
+
     /**
      * Test close
      */
@@ -143,10 +138,10 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         $sessionHandler = $this->createSessionHandler($storageClient, $tableName);
         $sessionHandler->open();
         $result = $sessionHandler->close();
-        
+
         $this->assertTrue($result);
     }
-    
+
     /**
      * Test read
      */
@@ -156,16 +151,16 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         $tableName = $this->generateName();
         $sessionHandler = $this->createSessionHandler($storageClient, $tableName);
         $sessionHandler->open();
-        
+
         $sessionId = $this->session_id();
         $sessionData = serialize( 'PHPAzure' );
         $sessionHandler->write($sessionId, $sessionData);
-        
+
         $result = unserialize( $sessionHandler->read($sessionId) );
-        
+
         $this->assertEquals('PHPAzure', $result);
     }
-    
+
     /**
      * Test write
      */
@@ -176,17 +171,17 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
             $tableName = $this->generateName();
             $sessionHandler = $this->createSessionHandler($storageClient, $tableName);
             $sessionHandler->open();
-            
+
             $sessionId = $this->session_id();
             $sessionData = serialize( 'PHPAzure' );
             $sessionHandler->write($sessionId, $sessionData);
-            
-            
+
+
             $verifyResult = $storageClient->retrieveEntities($tableName);
             $this->assertEquals(1, count($verifyResult));
         }
     }
-    
+
     /**
      * Test destroy
      */
@@ -196,18 +191,18 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         $tableName = $this->generateName();
         $sessionHandler = $this->createSessionHandler($storageClient, $tableName);
         $sessionHandler->open();
-        
+
         $sessionId = $this->session_id();
         $sessionData = serialize( 'PHPAzure' );
         $sessionHandler->write($sessionId, $sessionData);
-        
+
         $result = $sessionHandler->destroy($sessionId);
         $this->assertTrue($result);
-        
+
         $verifyResult = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(0, count($verifyResult));
     }
-    
+
     /**
      * Test gc
      */
@@ -217,16 +212,16 @@ class Zend_Service_WindowsAzure_SessionHandlerTest extends PHPUnit_Framework_Tes
         $tableName = $this->generateName();
         $sessionHandler = $this->createSessionHandler($storageClient, $tableName);
         $sessionHandler->open();
-        
+
         $sessionId = $this->session_id();
         $sessionData = serialize( 'PHPAzure' );
         $sessionHandler->write($sessionId, $sessionData);
-        
+
         sleep(1); // let time() tick
-        
+
         $result = $sessionHandler->gc(0);
         $this->assertTrue($result);
-        
+
         $verifyResult = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(0, count($verifyResult));
     }
