@@ -16,15 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /** Zend_Service_WindowsAzure_Storage_TableEntityQuery */
 require_once 'Zend/Service/WindowsAzure/Storage/TableEntityQuery.php';
 
@@ -33,12 +28,12 @@ require_once 'Zend/Service/WindowsAzure/Storage/TableEntityQuery.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_TestCase
 {
-    
+
     /**
      * Test all records query
      */
@@ -47,10 +42,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
         $target = new Zend_Service_WindowsAzure_Storage_TableEntityQuery();
         $target->select()
                ->from('MyTable');
-               
+
         $this->assertEquals('MyTable()', $target->__toString());
     }
-    
+
     /**
      * Test partition key query
      */
@@ -60,10 +55,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
         $target->select()
                ->from('MyTable')
                ->wherePartitionKey('test');
-               
+
         $this->assertEquals('MyTable(PartitionKey=\'test\')', $target->__toString());
     }
-    
+
     /**
      * Test row key query
      */
@@ -73,10 +68,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
         $target->select()
                ->from('MyTable')
                ->whereRowKey('test');
-               
+
         $this->assertEquals('MyTable(RowKey=\'test\')', $target->__toString());
     }
-    
+
     /**
      * Test identifier query
      */
@@ -87,10 +82,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
                ->from('MyTable')
                ->wherePartitionKey('test')
                ->whereRowKey('123');
-               
+
         $this->assertEquals('MyTable(PartitionKey=\'test\', RowKey=\'123\')', $target->__toString());
     }
-    
+
     /**
      * Test top records query
      */
@@ -100,10 +95,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
         $target->select()
                ->from('MyTable')
                ->top(10);
-               
+
         $this->assertEquals('MyTable()?$top=10', $target->__toString());
     }
-    
+
     /**
      * Test order by query
      */
@@ -113,10 +108,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
         $target->select()
                ->from('MyTable')
                ->orderBy('Name', 'asc');
-               
+
         $this->assertEquals('MyTable()?$orderby=Name asc', $target->__toString());
     }
-    
+
     /**
      * Test order by multiple query
      */
@@ -127,10 +122,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
                ->from('MyTable')
                ->orderBy('Name', 'asc')
                ->orderBy('Visible', 'desc');
-               
+
         $this->assertEquals('MyTable()?$orderby=Name asc,Visible desc', $target->__toString());
     }
-    
+
     /**
      * Test where query
      */
@@ -140,10 +135,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
         $target->select()
                ->from('MyTable')
                ->where('Name eq ?', 'Maarten');
-               
+
         $this->assertEquals('MyTable()?$filter=Name eq \'Maarten\'', $target->__toString());
     }
-    
+
     /**
      * Test where array query
      */
@@ -153,10 +148,10 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
         $target->select()
                ->from('MyTable')
                ->where('Name eq ? or Name eq ?', array('Maarten', 'Vijay'));
-               
+
         $this->assertEquals('MyTable()?$filter=Name eq \'Maarten\' or Name eq \'Vijay\'', $target->__toString());
     }
-    
+
     /**
      * Test where multiple query
      */
@@ -167,7 +162,7 @@ class Zend_Service_WindowsAzure_TableEntityQueryTest extends PHPUnit_Framework_T
                ->from('MyTable')
                ->where('Name eq ?', 'Maarten')
                ->andWhere('Visible eq true');
-               
+
         $this->assertEquals('MyTable()?$filter=Name eq \'Maarten\' and Visible eq true', $target->__toString());
     }
 }
