@@ -16,15 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /** Zend_Service_WindowsAzure_Storage_TableEntity */
 require_once 'Zend/Service/WindowsAzure/Storage/TableEntity.php';
 
@@ -33,12 +28,12 @@ require_once 'Zend/Service/WindowsAzure/Storage/TableEntity.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_TableEntityTest extends PHPUnit_Framework_TestCase
 {
-    
+
     /**
      * Test constructor
      */
@@ -48,7 +43,7 @@ class Zend_Service_WindowsAzure_TableEntityTest extends PHPUnit_Framework_TestCa
         $this->assertEquals('partition1', $target->getPartitionKey());
         $this->assertEquals('000001',     $target->getRowKey());
     }
-    
+
     /**
      * Test get Azure values
      */
@@ -56,20 +51,20 @@ class Zend_Service_WindowsAzure_TableEntityTest extends PHPUnit_Framework_TestCa
     {
         $target = new TSETTest_TestEntity('partition1', '000001');
         $result = $target->getAzureValues();
-        
+
         $this->assertEquals('Name',       $result[0]->Name);
         $this->assertEquals(null,         $result[0]->Value);
-        
+
         $this->assertEquals('Age',        $result[1]->Name);
         $this->assertEquals('Edm.Int64',  $result[1]->Type);
-        
+
         $this->assertEquals('Visible',    $result[2]->Name);
         $this->assertEquals(false,        $result[2]->Value);
-        
+
         $this->assertEquals('partition1', $result[3]->Value);
         $this->assertEquals('000001',     $result[4]->Value);
     }
-    
+
     /**
      * Test set Azure values
      */
@@ -82,17 +77,17 @@ class Zend_Service_WindowsAzure_TableEntityTest extends PHPUnit_Framework_TestCa
             'Age' => 25,
             'Visible' => true
         );
-        
+
         $target = new TSETTest_TestEntity();
         $target->setAzureValues($values);
-        
+
         $this->assertEquals('partition1', $target->getPartitionKey());
         $this->assertEquals('000001',     $target->getRowKey());
         $this->assertEquals('Maarten',    $target->FullName);
         $this->assertEquals(25,           $target->Age);
         $this->assertEquals(true,         $target->Visible);
     }
-    
+
     /**
      * Test set Azure values
      */
@@ -102,17 +97,17 @@ class Zend_Service_WindowsAzure_TableEntityTest extends PHPUnit_Framework_TestCa
             'PartitionKey' => 'partition1',
             'RowKey' => '000001'
         );
-        
+
         $exceptionRaised = false;
         $target = new TSETTest_TestEntity();
-        try 
+        try
         {
             $target->setAzureValues($values, true);
         }
         catch (Exception $ex) {
             $exceptionRaised = true;
         }
-        
+
         $this->assertTrue($exceptionRaised);
     }
 }
@@ -126,12 +121,12 @@ class TSETTest_TestEntity extends Zend_Service_WindowsAzure_Storage_TableEntity
      * @azure Name
      */
     public $FullName;
-    
+
     /**
      * @azure Age Edm.Int64
      */
     public $Age;
-    
+
     /**
      * @azure Visible Edm.Boolean
      */
