@@ -16,16 +16,10 @@
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 
-
-/**
- * Test helpers
- */
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 /** Zend_Service_WindowsAzure_Storage_Table */
 require_once 'Zend/Service/WindowsAzure/Storage/Table.php';
 
@@ -34,18 +28,18 @@ require_once 'Zend/Service/WindowsAzure/Storage/Table.php';
  * @package    Zend_Service_WindowsAzure
  * @subpackage UnitTests
  * @version    $Id$
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestCase
 {
-    
+
     protected static $uniqId = 0;
-    
+
     public function __construct()
     {
     }
-    
+
     /**
      * Test setup
      */
@@ -55,7 +49,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
             $this->markTestSkipped('This test case requires TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_RUNTESTS to be enabled.');
         }
     }
-    
+
     /**
      * Test teardown
      */
@@ -70,7 +64,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
             try { $storageClient->deleteTable(TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_TABLENAME_PREFIX . $i); } catch (Exception $e) { }
         }
     }
-    
+
     protected function createStorageInstance()
     {
         $storageClient = null;
@@ -79,20 +73,20 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         } else {
             $storageClient = new Zend_Service_WindowsAzure_Storage_Table(TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_HOST_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_ACCOUNT_DEV, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_KEY_DEV, true, Zend_Service_WindowsAzure_RetryPolicy_RetryPolicyAbstract::retryN(10, 250));
         }
-        
+
         if (TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY) {
             $storageClient->setProxy(TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_USEPROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_PORT, TESTS_ZEND_SERVICE_WINDOWSAZURE_STORAGE_PROXY_CREDENTIALS);
         }
 
         return $storageClient;
     }
-    
+
     protected function generateName()
     {
         self::$uniqId++;
         return TESTS_ZEND_SERVICE_WINDOWSAZURE_TABLE_TABLENAME_PREFIX . self::$uniqId;
     }
-    
+
     /**
      * Test create table
      */
@@ -100,15 +94,15 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
     {
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
-        
+
         $result = $storageClient->createTable($tableName);
         $this->assertEquals($tableName, $result->Name);
-        
+
         $result = $storageClient->listTables();
         $this->assertEquals(1, count($result));
         $this->assertEquals($tableName, $result[0]->Name);
     }
-    
+
     /**
      * Test table exists
      */
@@ -117,17 +111,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName1 = $this->generateName();
         $tableName2 = $this->generateName();
         $storageClient = $this->createStorageInstance();
-        
+
         $storageClient->createTable($tableName1);
         $storageClient->createTable($tableName2);
 
         $result = $storageClient->tableExists($tableName2);
         $this->assertTrue($result);
-        
+
         $result = $storageClient->tableExists(md5(time()));
         $this->assertFalse($result);
     }
-    
+
     /**
      * Test list tables
      */
@@ -136,7 +130,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName1 = $this->generateName();
         $tableName2 = $this->generateName();
         $storageClient = $this->createStorageInstance();
-        
+
         $storageClient->createTable($tableName1);
         $storageClient->createTable($tableName2);
 
@@ -145,7 +139,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $this->assertEquals($tableName1, $result[0]->Name);
         $this->assertEquals($tableName2, $result[1]->Name);
     }
-    
+
     /**
      * Test delete table
      */
@@ -153,14 +147,14 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
     {
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
-        
+
         $storageClient->createTable($tableName);
         $storageClient->deleteTable($tableName);
-        
+
         $result = $storageClient->listTables();
         $this->assertEquals(0, count($result));
     }
-    
+
     /**
      * Test insert entity
      */
@@ -169,17 +163,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $result = $storageClient->insertEntity($tableName, $entity);
 
         $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
         $this->assertNotEquals('', $result->getEtag());
         $this->assertEquals($entity, $result);
     }
-    
+
     /**
      * Test insert entity, with XML in content. This should not break the XML sent to Windows Azure.
      */
@@ -188,18 +182,18 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
         $entity->FullName = 'XML <test>'; // this should work without breaking the XML
-        
+
         $result = $storageClient->insertEntity($tableName, $entity);
 
         $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
         $this->assertNotEquals('', $result->getEtag());
         $this->assertEquals($entity, $result);
     }
-    
+
     /**
      * Test delete entity, not taking etag into account
      */
@@ -208,17 +202,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $result = $storageClient->insertEntity($tableName, $entity);
-        
+
         $this->assertEquals($entity, $result);
-        
+
         $storageClient->deleteEntity($tableName, $entity);
     }
-    
+
     /**
      * Test delete entity, taking etag into account
      */
@@ -227,17 +221,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $result = $storageClient->insertEntity($tableName, $entity);
 
         $this->assertEquals($entity, $result);
 
         // Set "old" etag
         $entity->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
-        
+
         $exceptionThrown = false;
         try {
             $storageClient->deleteEntity($tableName, $entity, true);
@@ -246,7 +240,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-    
+
     /**
      * Test retrieve entity by id
      */
@@ -255,16 +249,16 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $storageClient->insertEntity($tableName, $entity);
-        
+
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey(), 'TSTest_TestEntity');
         $this->assertEquals($entity, $result);
     }
-    
+
     /**
      * Test retrieve entity by id (> 256 key characters)
      */
@@ -273,18 +267,18 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
         $entity->setPartitionKey(str_repeat('a', 200));
         $entity->setRowKey(str_repeat('a', 200));
-        
+
         $storageClient->insertEntity($tableName, $entity);
-        
+
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey(), 'TSTest_TestEntity');
         $this->assertEquals($entity, $result);
     }
-    
+
     /**
      * Test retrieve entity by id, DynamicTableEntity
      */
@@ -293,17 +287,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $storageClient->insertEntity($tableName, $entity);
-        
+
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey());
         $this->assertEquals($entity->FullName, $result->Name);
         $this->assertType('Zend_Service_WindowsAzure_Storage_DynamicTableEntity', $result);
     }
-    
+
     /**
      * Test update entity, not taking etag into account
      */
@@ -312,13 +306,13 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $storageClient->insertEntity($tableName, $entity);
         $entity->Age = 0;
-        
+
         $result = $storageClient->updateEntity($tableName, $entity);
 
         $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
@@ -326,7 +320,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $this->assertEquals(0, $result->Age);
         $this->assertEquals($entity, $result);
     }
-    
+
     /**
      * Test update entity, taking etag into account
      */
@@ -335,16 +329,16 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $storageClient->insertEntity($tableName, $entity);
         $entity->Age = 0;
-        
+
         // Set "old" etag
         $entity->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
-        
+
         $exceptionThrown = false;
         try {
             $storageClient->updateEntity($tableName, $entity, true);
@@ -353,7 +347,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-    
+
     /**
      * Test merge entity, not taking etag into account
      */
@@ -362,19 +356,19 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $storageClient->insertEntity($tableName, $entity);
-        
+
         $dynamicEntity = new Zend_Service_WindowsAzure_Storage_DynamicTableEntity($entity->getPartitionKey(), $entity->getRowKey());
         $dynamicEntity->Myproperty = 10;
         $dynamicEntity->Otherproperty = "Test";
         $dynamicEntity->Age = 0;
-        
+
         $storageClient->mergeEntity($tableName, $dynamicEntity, false, array('Myproperty', 'Otherproperty')); // only update 'Myproperty' and 'Otherproperty'
-        
+
         $result = $storageClient->retrieveEntityById($tableName, $entity->getPartitionKey(), $entity->getRowKey());
 
         $this->assertNotEquals('0001-01-01T00:00:00', $result->getTimestamp());
@@ -384,7 +378,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $this->assertEquals($dynamicEntity->Myproperty, $result->Myproperty);
         $this->assertEquals($dynamicEntity->Otherproperty, $result->Otherproperty);
     }
-    
+
     /**
      * Test merge entity, taking etag into account
      */
@@ -393,20 +387,20 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(1);
         $entity = $entities[0];
-        
+
         $storageClient->insertEntity($tableName, $entity);
-        
+
         $dynamicEntity = new Zend_Service_WindowsAzure_Storage_DynamicTableEntity($entity->getPartitionKey(), $entity->getRowKey());
         $dynamicEntity->Myproperty = 10;
         $dynamicEntity->Otherproperty = "Test";
         $dynamicEntity->Age = 0;
-        
+
         // Set "old" etag
         $entity->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
-        
+
         $exceptionThrown = false;
         try {
             $storageClient->mergeEntity($tableName, $dynamicEntity, true);
@@ -415,7 +409,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-    
+
     /**
      * Test retrieve entities, all
      */
@@ -424,17 +418,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(20);
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         $result = $storageClient->retrieveEntities($tableName, 'TSTest_TestEntity');
         $this->assertEquals(20, count($result));
     }
-    
+
     /**
      * Test retrieve entities, all, DynamicTableEntity
      */
@@ -443,22 +437,22 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(20);
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(20, count($result));
-        
+
         foreach ($result as $item)
         {
             $this->assertType('Zend_Service_WindowsAzure_Storage_DynamicTableEntity', $item);
         }
     }
-    
+
     /**
      * Test retrieve entities, filtered
      */
@@ -467,17 +461,17 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(5);
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         $result = $storageClient->retrieveEntities($tableName, 'PartitionKey eq \'' . $entities[0]->getPartitionKey() . '\' and RowKey eq \'' . $entities[0]->getRowKey() . '\'', 'TSTest_TestEntity');
         $this->assertEquals(1, count($result));
     }
-    
+
     /**
      * Test retrieve entities, fluent interface
      */
@@ -486,13 +480,13 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(10);
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         $result = $storageClient->retrieveEntities(
             $storageClient->select()
                           ->from($tableName)
@@ -500,11 +494,11 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
                           ->andWhere('RowKey eq ?', $entities[0]->getRowKey()),
             'TSTest_TestEntity'
         );
-        
+
         $this->assertEquals(1, count($result));
         $this->assertEquals($entities[0], $result[0]);
     }
-    
+
     /**
      * Test retrieve entities, fluent interface
      */
@@ -513,13 +507,13 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(10);
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         $result = $storageClient->retrieveEntities(
             $storageClient->select()
                           ->from($tableName)
@@ -527,11 +521,11 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
                           ->andWhere('PartitionKey eq ?', $entities[0]->getPartitionKey()),
             'TSTest_TestEntity'
         );
-        
+
         $this->assertEquals(1, count($result));
         $this->assertEquals($entities[0], $result[0]);
     }
-    
+
     /**
      * Test retrieve entities, fluent interface, top specification
      */
@@ -540,22 +534,22 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(10);
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         $result = $storageClient->retrieveEntities(
             $storageClient->select()->top(4)
                           ->from($tableName),
             'TSTest_TestEntity'
         );
-        
+
         $this->assertEquals(4, count($result));
     }
-    
+
     /**
      * Test batch commit, success
      */
@@ -564,41 +558,41 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(20);
         $entities1 = array_slice($entities, 0, 10);
         $entities2 = array_slice($entities, 10, 10);
-        
+
         // Insert entities
         foreach ($entities1 as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-        
+
         // Insert entities in batch
         foreach ($entities2 as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         // Delete entities
         foreach ($entities1 as $entity)
         {
             $storageClient->deleteEntity($tableName, $entity);
         }
-        
+
         // Commit
         $batch->commit();
-        
+
         // Verify
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(10, count($result));
     }
-    
+
     /**
      * Test batch rollback, success
      */
@@ -607,27 +601,27 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(10);
-        
+
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-        
+
         // Insert entities in batch
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         // Rollback
         $batch->rollback();
-        
+
         // Verify
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(0, count($result));
     }
-    
+
     /**
      * Test batch commit, fail updates
      */
@@ -636,29 +630,29 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(10);
         foreach ($entities as $entity)
         {
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         // Make some entity updates with "old" etags
         $entities[0]->Age = 0;
         $entities[0]->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
         $entities[1]->Age = 0;
         $entities[1]->setEtag('W/"datetime\'2009-05-27T12%3A15%3A15.3321531Z\'"');
         $entities[2]->Age = 0;
-        
+
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-        
+
         // Update entities in batch
         $storageClient->updateEntity($tableName, $entities[0], true);
         $storageClient->updateEntity($tableName, $entities[1], true);
         $storageClient->updateEntity($tableName, $entities[2], true);
-        
+
         // Commit
         $exceptionThrown = false;
         try {
@@ -668,7 +662,7 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         }
         $this->assertTrue($exceptionThrown);
     }
-    
+
     /**
      * Test batch commit, fail partition
      */
@@ -677,20 +671,20 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
         $tableName = $this->generateName();
         $storageClient = $this->createStorageInstance();
         $storageClient->createTable($tableName);
-        
+
         $entities = $this->_generateEntities(10);
-        
+
         // Start batch
         $batch = $storageClient->startBatch();
         $this->assertType('Zend_Service_WindowsAzure_Storage_Batch', $batch);
-        
+
         // Insert entities in batch
         foreach ($entities as $entity)
         {
             $entity->setPartitionKey('partition' . rand(1, 9));
             $storageClient->insertEntity($tableName, $entity);
         }
-        
+
         // Commit
         $exceptionThrown = false;
         try {
@@ -699,32 +693,32 @@ class Zend_Service_WindowsAzure_TableStorageTest extends PHPUnit_Framework_TestC
             $exceptionThrown = true;
         }
         $this->assertTrue($exceptionThrown);
-        
+
         // Verify
         $result = $storageClient->retrieveEntities($tableName);
         $this->assertEquals(0, count($result));
     }
-    
+
     /**
      * Generate entities
-     * 
+     *
      * @param int 		$amount Number of entities to generate
      * @return array 			Array of TSTest_TestEntity
      */
     protected function _generateEntities($amount = 1)
     {
         $returnValue = array();
-        
+
         for ($i = 0; $i < $amount; $i++)
         {
             $entity = new TSTest_TestEntity('partition1', 'row' . ($i + 1));
             $entity->FullName = md5(uniqid(rand(), true));
             $entity->Age      = rand(1, 130);
             $entity->Visible  = rand(1,2) == 1;
-            
+
             $returnValue[] = $entity;
         }
-        
+
         return $returnValue;
     }
 }
@@ -738,12 +732,12 @@ class TSTest_TestEntity extends Zend_Service_WindowsAzure_Storage_TableEntity
      * @azure Name
      */
     public $FullName;
-    
+
     /**
      * @azure Age Edm.Int64
      */
     public $Age;
-    
+
     /**
      * @azure Visible Edm.Boolean
      */
