@@ -15,20 +15,15 @@
  * @category   Zend
  * @package    Zend_Soap
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: ClientTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: ClientTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Soap_ClientTest::main');
 }
 
-require_once dirname(__FILE__)."/../../TestHelper.php";
-
-/** PHPUnit Test Case */
-require_once "PHPUnit/Framework/TestCase.php";
-
 /** Zend_Soap_Server */
 require_once 'Zend/Soap/Server.php';
 
@@ -41,7 +36,7 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Soap
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Soap
  */
@@ -223,6 +218,48 @@ class Zend_Soap_ClientTest extends PHPUnit_Framework_TestCase
         $this->assertArrayNotHasKey('user_agent', $options);
     }
 
+    /**
+     * @group ZF-10542
+     */
+    public function testAllowNumericZeroAsValueForCacheWsdlOption()
+    {
+        $client = new Zend_Soap_Client();
+        $this->assertNull($client->getWsdlCache());
+        $options = $client->getOptions();
+        $this->assertArrayNotHasKey('cache_wsdl', $options);
+
+        $client->setWsdlCache(WSDL_CACHE_NONE);
+        $this->assertSame(WSDL_CACHE_NONE, $client->getWsdlCache());
+        $options = $client->getOptions();
+        $this->assertSame(WSDL_CACHE_NONE, $options['cache_wsdl']);
+
+        $client->setWsdlCache(null);
+        $this->assertNull($client->getWsdlCache());
+        $options = $client->getOptions();
+        $this->assertArrayNotHasKey('cache_wsdl', $options);
+    }
+
+    /**
+     * @group ZF-10542
+     */
+    public function testAllowNumericZeroAsValueForCompressionOptions()
+    {
+        $client = new Zend_Soap_Client();
+        $this->assertNull($client->getCompressionOptions());
+        $options = $client->getOptions();
+        $this->assertArrayNotHasKey('compression', $options);
+
+        $client->setCompressionOptions(SOAP_COMPRESSION_GZIP);
+        $this->assertSame(SOAP_COMPRESSION_GZIP, $client->getCompressionOptions());
+        $options = $client->getOptions();
+        $this->assertSame(SOAP_COMPRESSION_GZIP, $options['compression']);
+
+        $client->setCompressionOptions(null);
+        $this->assertNull($client->getCompressionOptions());
+        $options = $client->getOptions();
+        $this->assertArrayNotHasKey('compression', $options);
+    }
+
     public function testGetFunctions()
     {
         $server = new Zend_Soap_Server(dirname(__FILE__) . '/_files/wsdl_example.wsdl');
