@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_TimeSync
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: TimeSyncTest.php 21708 2010-03-31 17:38:37Z matthew $
+ * @version    $Id: TimeSyncTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__ ) . '/../TestHelper.php';
-
 /**
  * Zend_timeSync
  */
@@ -34,7 +29,7 @@ require_once 'Zend/TimeSync.php';
  * @category   Zend
  * @package    Zend_TimeSync
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_TimeSync
  */
