@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Uri
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id $
  */
@@ -24,11 +24,6 @@ if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_UriTest::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../TestHelper.php';
-
 /**
  * Zend_Uri
  */
@@ -43,7 +38,7 @@ require_once 'Zend/Config.php';
  * @category   Zend
  * @package    Zend_Uri
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Uri
  */
@@ -133,6 +128,39 @@ class Zend_UriTest extends PHPUnit_Framework_TestCase
         Zend_Uri::setConfig('This should cause an exception');
     }
 
+    /**
+     * Tests that if an exception is thrown when calling the __toString()
+     * method an empty string is returned and a Warning is triggered, instead
+     * of a Fatal Error being triggered.
+     *
+     * @group ZF-10405
+     */
+    public function testToStringRaisesWarningWhenExceptionCaught()
+    {
+        $uri = Zend_Uri::factory('http://example.com', 'Zend_Uri_ExceptionCausing');
+
+        set_error_handler(array($this, 'handleErrors'), E_USER_WARNING);
+
+        $text = sprintf('%s', $uri);
+
+        restore_error_handler();
+
+        $this->assertTrue(empty($text));
+        $this->assertTrue(isset($this->error));
+        $this->assertContains('Exception in getUri()', $this->error);
+
+    }
+
+    /**
+     * Error handler for testExceptionThrownInToString()
+     *
+     * @group ZF-10405
+     */
+    public function handleErrors($errno, $errstr, $errfile = '', $errline = 0, array $errcontext = array())
+    {
+        $this->error = $errstr;
+    }
+
     /**
      * Tests that an invalid $uri throws an exception and that the
      * message of that exception matches $regex.
@@ -189,6 +217,15 @@ class Zend_Uri_Mock extends Zend_Uri
     public function getUri() { }
     public function valid() { }
 }
+class Zend_Uri_ExceptionCausing extends Zend_Uri
+{
+    protected function __construct($scheme, $schemeSpecific = '') { }
+    public function valid() { }
+    public function getUri()
+    {
+        throw new Exception('Exception in getUri()');
+    }
+}
 class Fake_Zend_Uri
 {
 }
