@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: IpTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: IpTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /**
  * @see Zend_Validate_Ip
  */
@@ -34,7 +29,7 @@ require_once 'Zend/Validate/Ip.php';
  * @category   Zend
  * @package    Zend_Validate
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Validate
  */
@@ -122,8 +117,8 @@ class Zend_Validate_IpTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2694
-     * @see ZF-8253
+     * @group ZF-2694
+     * @group ZF-8253
      */
     public function testIPv6addresses()
     {
