@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FormErrorsTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: FormErrorsTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_FormErrorsTest::main() if this source file is executed directly.
@@ -25,8 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_View_Helper_FormErrorsTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../../TestHelper.php';
-
 require_once 'Zend/View/Helper/FormErrors.php';
 require_once 'Zend/View.php';
 
@@ -36,7 +34,7 @@ require_once 'Zend/View.php';
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_View
  * @group      Zend_View_Helper
@@ -50,7 +48,6 @@ class Zend_View_Helper_FormErrorsTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_View_Helper_FormErrorsTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -164,7 +161,7 @@ class Zend_View_Helper_FormErrorsTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @issue ZF-3477
+     * @group ZF-3477
      * @link http://framework.zend.com/issues/browse/ZF-3477
      */
     public function testCanSetClassAttribute()
