@@ -17,7 +17,7 @@
  * @subpackage UnitTests
  * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: FormTest.php 24201 2011-07-05 16:22:04Z matthew $
+ * @version    $Id: FormTest.php 24478 2011-09-26 19:52:58Z adamlundrigan $
  */
 
 // Call Zend_View_Helper_FormTest::main() if this source file is executed directly.
@@ -167,6 +167,18 @@ class Zend_View_Helper_FormTest extends PHPUnit_Framework_TestCase
         $form = $this->helper->form('FormName', array('action' => '/foo', 'method' => 'get'));
         $this->assertNotRegexp('/<form[^>]*(name="FormName")/', $form);
     }    
+
+    /**
+     * @group ZF-11747
+     */
+    public function testClosingTagIsPrintedWhenContentIsOmitted()
+    {
+        $form = $this->helper->form('FormName');
+        // Check that opening tag was printed
+        $this->assertContains('<form', $form);
+        // Check that closing tag was printed
+        $this->assertContains('</form>', $form);
+    }    
 }
 
 // Call Zend_View_Helper_FormTest::main() if this source file is executed directly.
