@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: SitemapTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: SitemapTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 require_once dirname(__FILE__) . '/TestAbstract.php';
@@ -31,7 +31,7 @@ require_once 'Zend/View/Helper/Navigation/Sitemap.php';
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_View
  * @group      Zend_View_Helper
@@ -217,14 +217,14 @@ class Zend_View_Helper_Navigation_SitemapTest
     public function testThrowExceptionOnInvalidLoc()
     {
         $nav = clone $this->_nav2;
-        $nav->addPage(array('label' => 'Invalid', 'uri' => 'http://w.'));
+        $nav->addPage(array('label' => 'Invalid', 'uri' => 'http://w..'));
 
         try {
             $this->_helper->render($nav);
         } catch (Zend_View_Exception $e) {
             $expected = sprintf(
                     'Encountered an invalid URL for Sitemap XML: "%s"',
-                    'http://w.');
+                    'http://w..');
             $actual = $e->getMessage();
             $this->assertEquals($expected, $actual);
             return;
