@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: PartialLoopTest.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: PartialLoopTest.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
 // Call Zend_View_Helper_PartialLoopTest::main() if this source file is executed directly.
@@ -25,10 +25,6 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_View_Helper_PartialLoopTest::main");
 }
 
-require_once dirname(dirname(dirname(dirname(__FILE__)))) . '/TestHelper.php';
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
-
 /** Zend_View_Helper_PartialLoop */
 require_once 'Zend/View/Helper/PartialLoop.php';
 
@@ -44,7 +40,7 @@ require_once 'Zend/Controller/Front.php';
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_View
  * @group      Zend_View_Helper
@@ -68,7 +64,6 @@ class Zend_View_Helper_PartialLoopTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_View_Helper_PartialLoopTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -274,8 +269,8 @@ class Zend_View_Helper_PartialLoopTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3350
-     * @see ZF-3352
+     * @group ZF-3350
+     * @group ZF-3352
      */
     public function testShouldNotCastToArrayIfObjectIsTraversable()
     {
@@ -301,7 +296,7 @@ class Zend_View_Helper_PartialLoopTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3083
+     * @group ZF-3083
      */
     public function testEmptyArrayPassedToPartialLoopShouldNotThrowException()
     {
@@ -324,7 +319,7 @@ class Zend_View_Helper_PartialLoopTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2737
+     * @group ZF-2737
      * @link http://framework.zend.com/issues/browse/ZF-2737
      */
     public function testPartialLoopIncramentsPartialCounter()
@@ -349,7 +344,7 @@ class Zend_View_Helper_PartialLoopTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-5174
+     * @group ZF-5174
      * @link http://framework.zend.com/issues/browse/ZF-5174
      */
     public function testPartialLoopPartialCounterResets()
