@@ -15,13 +15,12 @@
  * @category   Zend
  * @package    Zend_View
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StubEmpty.php 20096 2010-01-06 02:05:09Z bkarwin $
+ * @version    $Id: StubEmpty.php 23775 2011-03-01 17:25:24Z ralph $
  */
 
-require_once 'PHPUnit/Util/Filter.php';
 
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
+
 
 // used to test when helper file is loaded but class is not within
